#!/usr/bin/env python
"""
    Images stored as PhotoImage objects, for buttons and logos.
    Created Oct 2008
    Copyright (C) Damien Farrell

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
"""

import tkinter as tk

def tableapp_logo():
     img = tk.PhotoImage(format='gif',data=
            'R0lGODlhXQFdAffEAAAAAAMDGwoKIAwMKAUHIwoNOREROD4nIksZGEIWB04x'
            +'K3wlPkZDOBwdXSoWTB0dYBkbaR4ccSMebh4jeyAgbCQkeCUieTYgZFUwS0wv'
            +'TlwwYEUofHYoa2wndnEkcmAhV1FJT2BCZK4vPrwxLf41FNwvPfo/Kvc3Ku0+'
            +'Nuc9O+o9OOgzOvQ+MLxcBrBMHrtqALh0BbhxGphPA8JXCslDFcpKDv9fCv5B'
            +'H/pNHP9VEvRbFvdTG/hRHP9YG+9nD+5sDOptAPBpDvdnC+p1ButzCPl4A/Fj'
            +'Ed5BPv1FI/5DOuJbJM9pJ8RyAZgtTpQsVYkrXqUuRJozfq8waLc3Zbk3ZL04'
            +'YLI2aqc1c6o1crovZt08RNQ6TMc5V8o5VMUzU+E8QbtLVvd5R8trbrqIDLiS'
            +'HrmNOLipPeaFAuaPBumFAPSKAOaVCeaZCvWbA+eKG+arD+miB+anEOarEeax'
            +'FOu1EPWxCduMJuyHIemVJOa3Jea6Iea8NubFKebKLObNP7iwUOmuT+bPQubQ'
            +'RubSS+XZTebWVebXWebZX+fHXurlXubcZObea+jZY/PsaObjcublf+Xjbi4f'
            +'gjkekiwmiiYjjjgmniscqD4js0Ugk3U2h24mnX0ul3Mtn3ornEUms0smvEcm'
            +'uVcot1wps1Inu1gouHEsoXguqm0rpFtbg3ZcqEclw40tjocwj5IyhpgziIIv'
            +'k4gwkJxrscVvgum9iefnh+bog+vrnfn7nu3to+7vquz1pfHxt/Hxvfb/vf/M'
            +'w/Pzw///xvf4yvj42/j32////wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAAAAAAALAAAAABdAV0BAAj+AAEIHEiwoMGD'
            +'CBMqXMiwocOHECNKNBiAYUWCFydq3Mixo0eOMmbMaNFC5EiTJZmQLFnS5AyV'
            +'J0maZIKyJI2bOHPq3MmzZ08RIqAAHUoUqNChUKCUKMq06FGgY6JKnWpnqtWr'
            +'Uqtiveqkq9cnTsA6uRLWq9mzXcWaJStWLMolLuOOhCv3bd26PvPq3Xvzhd+/'
            +'fpkAHvxXMGHAhg/LENiCCJEfjyE/DvKjsmPIkIM41kyE8uPLkR2D3kGaNA8e'
            +'PXqURr06NY/SO1T3eI36dWnVsXeg3sK7t+/fvL8AH048+JY4cuLEqZNceRw4'
            +'cd44r6O8OXPlb97AkS49Dp3qyan+K8dipbz58+jNYyFvhX378+7Vmw9CP4gP'
            +'+kbq0xeiP0h+/fzp919/PtwXxGynxTYbbAjaJpuDsMV22mmpRTjbGWcMcUYa'
            +'GHaYBocdYsjhiCCKuGGIHWoI4gsCzSCZZKLFaBmMnW0G2os2fvZDhDya1iNs'
            +'tgEp5Go8FGfkkUge59yS2HXHpHPNNQndk0zKIUd66bEXH5byobelfj78QF+B'
            +'AoZJ2YD9UeYDmvWJ+YMPrP0o55ByBrkaiiniiaKGeZ6oJ54sAtACZpjpKJlm'
            +'hH7WWaGFfsbZZ3NGKmmkSVZqqZJUZqrppplyieWWXXqKZZqkEqimmGmSmeqb'
            +'Pkzq6qv+pO0pK4Z86llriLXmekagjVkW2oyIGhpaZIxmthlmsCZL6aXMFsfp'
            +'s9B2Wp6WoWZpbZfuaVnqmKQWGKa3b9LHan/5vSmmsuj2eOufs2bYLrsY8orj'
            +'ZY3e+BgQoOX7YrE7pusvac0GDFy0BBOcBZfZiqowl/qh2qaqYFYGsX33OTzm'
            +'twX++2+fHK8LL60fyzsjo46SzC+xI+tIhMb+CuwybwXHzCl8CpMX35agvjet'
            +'Fd2G62bF39pnrpmUqXnqt6yynK6eJba7rsfugtwhryr7Om9lPwyR6K83JlqZ'
            +'Ekor+7LLUcpstnM7f8olFa6knXOoWNyn6rhCG1gf0KxWTCr+q+b+gFvYr3LM'
            +'RMcfS40nnxoGKgPJXEc2hNb0Kpry1Y/ZCbikYwt89ubVpUcFFdeaBzrCOudM'
            +'9LgSh+mwgd6C67rdRZPZ6uWBFy6rrraySzWhWBuKde+NFvsZvpD/AATtr2Ye'
            +'MOecJ2xF26TX7Cl7fMtNcdBtHh0u0aqzLnfSyE8a9fi452544fIqWvVnWuP4'
            +'u+T2Ah/+pMo3y/zmC7+t9v7mmWufmmaqTBjqJrfv0e1/dxvam+YnKdtxDF4e'
            +'G1yKeBWm4TkOCF6DDAZPBj+rrYyBc6qfb7qApPudLW06Wxj/FBa01/kPgGIy'
            +'kwwlBsMCjStjIJTTA3d4PvL1EFf+6eNd++olmSXgq1AYRJnkkJXDH4nwUiY0'
            +'mwpvFjqaOc8KSAugDcNFsaHZEGlhQFUWFTi7JvLocOZz4J9qtbthEWGIhkqi'
            +'5JLovmFVxow9eqKlyhZFaF3RZqFbzwq5BLvW5S2GqmsY7MYkMb6Jq4x4LM34'
            +'PCTBdjGhabnzWBD51b6qTU5YxkvZByNZGmaRMHN9jJkKUzi9VupMe6kbGgGR'
            +'9kgCYUyWkCQlrtZYuFpdkl2JY4wnVbY+k3GNUUNIIilho8dKpbJgU6yWl1bJ'
            +'swTqTVxcLGAAu2i3G1psmZKcFdQgmKLyTY0xjONdOo1JrGH2C5zNTNIzCTbN'
            +'/KkHZ9X+co/QjmbD/30xdYY02t2upx9wxuqHGJIg4njYyyFQUHj7wswRL0NH'
            +'JEqueO9cZjxLOE8/ppBaV1xlSHmmzRaKq2iObN3FHknDyqjJoDu4lccwqadK'
            +'yvSBIkOi10DZuPdxEKaXOiUqO/osamYJnzXDQuwOmMBDthBVXLSmqnIZSXLu'
            +'EqFqbONO1RfK4NmRnZAB6kaNRNSiYque0kMreu4mO6nuk1vbs5g1XUofmBJu'
            +'ocDkZQ8dis4O/mpy6RQN734l1rESp6wzo+Yf1Uqz9kCVMjSEYd1O+sVFPtJ1'
            +'GdWlGhOq13GGaHeBtdpOE9VJ4CmqsIYdGGI1hcLWGhVu6Vn+pPUAqFKWds9M'
            +'YSxg3nAIzjPYVK9+8qzgPtvXGekIg5DT13F9KtiKoja1vlktaxvrpcVSt5Vp'
            +'wlrE3noxR2Kzb91boEH9hMZeXhVPIAqmoHywPscBb6uFSm4df5AgjUJXtdJ9'
            +'EmP3y0pBRg9rlUVa3/ypRS/2k5ZbtOt58YpVj5lzV8I0GTIfY0T3QdR467Mc'
            +'Hu+L3/xCKZr8HWR5IotA3cruZ2C6bAvvIwTw9RarwE3jn0RWsq5hDV8l41cG'
            +'Z6RhM3L4Nx7WLyDloz8RI+yfuDxkw5YcUNvmzaA82KyMhUtcQTEqWMCKH2cS'
            +'hWXG4SBSPYZVj38c3Uw5ycycOrP+fl9LRXuep3XarJ7FwMUtyggBCGAypA+E'
            +'oLEwR6oHT2Oog2PMIfXOoAiIFoIQEF2ERTfa0Y1ONKQdrehEI/oxkUZ0Djad'
            +'AxtwmtOeBvWnR71pT4c61KLmNJl7U4dWu/rVsI61rGc9aypkYQqfs8IUdj2F'
            +'KvD611X4nLCF/etiG3sKRQhCsu+s6Ba3WNlBAIKipe3sIEwbg81eNL4qzZ8f'
            +'CCE14A53anLQA3KLG9zkJve3y43udqfGCD1Qg7znLe800Pve9ca3vvetBiYI'
            +'RAEAD7jAB07wghuc4JlIuMIT3oGFO5zhD89Ewxc+8YhX4eJeqELGL87xi3OB'
            +'ClzouMb+L/45kXecClUIecqrAIKWtzwEL4+5y2Eec5rLvOYuB4HNQVCKUpzi'
            +'56kwxc9PwQmhD/0UpTBFKpL+85433edI97kpSsGJUxjdFGCoAhi2nnWuc13r'
            +'XQc7GLjgdbGHfetmBwMCFICAtrMdAQdw+9rbTncFxH3ub5e73udO9wOE4O+A'
            +'D7zgNSD4vxO+8CE4vOEFnwGBFODxBni85CE/eclHvvIFuDzmMX+Jznv+Ep74'
            +'vOg7H/rRm/70nS/P6FQ4BSmgZwrmyYLrRTf780QgAhCIAAUkkPvcU+D2ved9'
            +'7nE/fNxHQALG/z3xb3985qtiFJ8YxfNJoYrnS7/6z88+9qX+f33tY7/61P+E'
            +'9VVxhfKb/wrrKT8WXOEKLJy//FG4QvzT//74v9/8BCCAAPLP/wDwfwD8F4D+'
            +'l38AKAACAIAE+H8KmH+U0IAO+IAQGIESOIESGAECMQAGkIEauIEbmHkc+IEg'
            +'CIKeMIKgN4ImWAkmGHopOIIouIIk+IImWIKgB3tWsHq6Bns4KDo0qGs8uGs3'
            +'qHo3mIPlQQFEWIRGeIREKAFIuIRLCAFHOApQGIVSqAqkIApQSApQSIWkgIVR'
            +'uIVXuIVcKIVReH/qtx5maAX3Z4bqR4ZseAUG+IZwGIdyOId0WIeTcId4mId6'
            +'uId82Id8SAEXGIKCOIiEqIGe0IL+MPiCiMiCLtiIh7iCoIeCO1iD57GDoJNr'
            +'oEODrUeDNrh6uTaETBiKojiKTyiGpniKqJiKp/h+7teGrviK91eHsjiLtGiA'
            +'fniLuJiLkyABgViIvviLBnCCwuiCi8iIiIiCkbiCxYhrlJiJOVh76TGJPlge'
            +'tceM5XEwpJiN2liKqtiN3oiKawiLrOiKrciGtXiO6GiLuriO7MiLAACM8EiI'
            +'yjiMjOiIxViMxOgJ5+F6rdeDzDg6l9iD5cGJukYFmsiMsLeNCpmN39iQDjkK'
            +'4hiREumG6ViRssiOGJmL7oiB8diRHFiPjpiPKYiPjziSKUiJBbmD/8gl/DiQ'
            +'o3OQ1Gj+HlOwkDQZig95k6qYhuE4kRJpkT45hxkZlH24kR5ZlBlYkvb4iCVI'
            +'j0s5ki14jJ4ghNJYiTVokEIYkAP5gzg4ezNZk15phDgZlqaIfuJYjjxJluf3'
            +'k2r5hkLZlnnojkZplCY5l3SZlCF5kj/Ig1IAk9VoBXvJgykphFmZlV9ZmBQg'
            +'logJhWfZhmb5inMYAGt5jm45mUQZlx1Jkk/ZiPiIgvdokiU4jTgImgOpiS2J'
            +'kgT5koAJe1RgmF+ZmIi5mLBZhpH5kwEwmW5ZmZYJj/N4l4tIkiCJlCSoiS5J'
            +'jcKZmtYIe3tpg34pmFbAml7pmmIJi415ftO5k2mIBbP5k7b+2ZZwmZvxeJeP'
            +'2Jn0+JvASYIyKTqXeIn8GJoFeZ6AqZ6jCYrOuZDQGZZnWZ08CZnZWZHbKZS4'
            +'6Z2+SI+YKZLjuZkmCAY/qJzxuTCiqZUBOZ80WZ84GZtliZZpuZ/82Z8Z+Z8A'
            +'Ko/4mIzgOaC7GZzuCYS55oMNKmyp6XoKKp8Qqo0SepOLiZ89iaEGqJ+zqKEb'
            +'2osdWogmKaLjWZK+OYyDuaCD+Y9UAI2qp6B/WZXN+aLbGKMPKZE0qpOuaKPp'
            +'qKMYCYgAwJE9Ko8EipTiSZJNCZzsmYMKOolZaY06KJXmAaVRKqUNSaEWWqEU'
            +'iaW1qKXtKBBfWogDEJJAGqInWKb+lwCYhgqEWhmNqnmJu5aJ5jF7qwmnDCmn'
            +'3wib7jedVWp+6Yijs6mn68ihffqBggqVvsmZmlmPVLmJBomS54mQfhmNnpiV'
            +'kSqpo0iplTqRmSqd2ImneeqpGsmnoTqIKgiV4MmIZVqXK4igKEqDfzk6f7mX'
            +'bKqa+7ikRUqrpGir3RgKdBqRl1p+VvCTABCZvvqrXRqsglieAoqUTSmed1mN'
            +'ysmciEqJmyiQhqqaXWmtNomtqpir2xqLvEqL44qLoGquRymMQzqi5GmM9VgJ'
            +'xVmD0xifnbimr7egOIivoqiv+9qvdnqn/2qHAeuHA0uwBhqm7BqkK6iakDqc'
            +'ikqNVkn+scJ5kLpnsUsYChgLjtLJrYx5oY+JpeHKlh87lMBKsKJalwebsMB5'
            +'j5fwssW5qj6YpImagw97kDTohDKLhDVrs7HJr/7asR77s3sYsuYKqOmKrCpY'
            +'rFLwObyWqJTIoqwqnFypa38pmFV7hBAgAQ9JffWZsxq7tVwLlF77tUErtBs4'
            +'niXYm8JYuCBpqokblUXqOYcan1IbjTJ5r/NJtaKIfDcZhom5t90Ki33btX+L'
            +'h2AbrCVZpoGKiMeKsHq5pmoKmKUJmn2ZlxU7ipZLihKghKOohHerua9JpRrr'
            +'k5yqnaH7ljwquAVbeuharCR4CZ2Jj+7ZpLvGoqu6qvWalVj+oKxbuYO2i7u2'
            +'G7PX6pBUmLfbqrWa+rl+q4eU8LNcOgCZZ3mP5wCVp3nxu3mTx76Th3qXYAn4'
            +'q7/4+3ml13n661/m4QSt53pOQI1SIHtSsMCvegX7SB4LHMESbAUQUMEWfMEY'
            +'nMEavMEbHH0e/AkgLH6qAAqg8MHPJ36X8MElDIWgwMIhvH0tPH/mV472J3/m'
            +'FwWYigU1DH833IpREABAHMRCPMREXMRGLABFTIFKvMRMTAkTIBAHAHAMcHAD'
            +'N8UCZ8VWTHBZrAAMkApe/MVgHMZiPMZkTMZiAAZicMZonMZrzMZu7MZovMZy'
            +'nMZnTMdyjAp4nMd6vMd83Md+7Mf+YPwKgRwLYizIXkzIX2zIiRzIqYDIqeB1'
            +'kBzJkjzJlOx1OXfJLscAmLzJnJzJmIx4oKx4i1d4ogx4pdx4ADAGbbDKrFwH'
            +'rLzKcAAHr+zKr1zLbUDLrfzKt7DLu6wLvOzLvBzMtwDMvyzMxCzMv5wIyrzM'
            +'zNzMzvzMiUAI0NzMwFDN1nzN2JzN2rzN29wI3vzN4BzOkODNjPDN5RzO6PzN'
            +'iQDOsdzO7vzO8BzP7qwd89zObAAHvWDNwZDPwJDPvxAM2czP1fwLAl3QwPDP'
            +'AQ0MbaAGtszKDN0Ga9DQEv3KstzQMCAQMLAGbLDRa9DRGs3RIM0GHi3SIS3S'
            +'I83RGt3+0WxgCyyNC7bg0i2tCy/N0jRtCzI90y+NCzDd0jOt0zpd04ZwCEJ9'
            +'CIkw1EQ91IRg1EZtCEWt1Eg91EE91LzwC1PNC1Zt1VRd1Ved1VTN1Vud1Vdd'
            +'1V091YtQ1osACZBg1mrNCGvN1mXt1miN1mct12q9CIoACYqw0Xq90bG81/e8'
            +'13AA2H59z4Et2Hq9C4jNC4mt2LvA2I1t1Yj92JCd2ItN2ZE92buABpq9Bprd'
            +'2Z3d0Z4d2p7N2aJd2mtw0QAAAyjt0SPN2q6t0q/t2ibN2j9d0zld07WN07fd'
            +'0rW907f9004d3MI93MQt1V7t1WKN1cq93GCt1c3N1XUd3dL+Pd3U7QjRDQmD'
            +'nd3avd3crddXfdmKHdaYHdbgTd6S/d2LPdqlvd7s3d6ejdoZPduxPd/0Xd8d'
            +'TdM/7du+3dO6nds8rdu2XdwCPuDBndzOfeAGrtXMHdbIbdXTbd3SDeF1LeFl'
            +'ndbUndfdneEaPtiL/d2Qzdji3eGTHd4eLuKK7d4onuKifQbwbd8u/uKu/d8u'
            +'DdMzTuM4beMAPuO7XeME3uMEzuDNjdVBPtVc/QtGDuRH/tVGTt1MrtYUvghP'
            +'Lt3YveFUruEfXuIkft4i/tiNzeVZTt4qHuYq3uIwXub2zd8yjt/9nea7feP/'
            +'bQs+HufEPdZfreBEruBDnuRALt7+dZ3WUf7kFB7l0S3hU17lhp7da5Dlkr3o'
            +'I47eV/7lV57eKE7aYu7eZF7maGDmsY3fNp7bO93pas7buP3pcC7npq7UYl3k'
            +'dn7kYJ3nd97qDF7dfW7Wgt7kdX3Sh57rbODhH+7lI/7YuRDWwX7Vwy7sYV3p'
            +'k57igZLRmt7sMa7ftq3jOA7q+g3tLn3q2C7U4r3tdy7eSW7keu7tRb7ksm7W'
            +'kDALtl7Xj6DuZe0Guv7uu97r6E3Z5M3txk7s254LyL7vog3fq+3smg7gbd7p'
            +'1e7moo7bLZ3t2E7n347gdL7qBw7rV23W6w7lUp7uFd/khQ7vh17vjO7x+H7v'
            +'9i7elO7+3iWf6fyOBv4u3wBf5pz+6Tg+6rZ94zCP4wp/6syN3Ay/3A6/4Myd'
            +'7mc96IuQ8WpN9NLN8boO4vLO649u1cXO7U9/7KFN2ief8lV/6S2v6dNe8P0N'
            +'823+9Th986b+8Ftt5wYe7nrO8M0N9NNt9Gz/0Uhf5Urf5Y4u3lHv9Haf71dt'
            +'8lMv2lWP4lif9fSd6az95giv5v7t34Yv6jAt9nIu8bD+8JL/3GXf6lRd7kLP'
            +'9hNe1nHf8dtO91x+3iM/8lGf8nzP3oEv+C/+8ozP09Pu+q4P6jXt+HFe+ZKf'
            +'4M8d+WVf55lP65oP9J1P5R0d+qJ/5XfPC1F//HbP738f5qn+r/pnTuqkvuah'
            +'bvA0TvC03+OGkODcj/u5r9yWL+S1bvG/P/QUL/TBHwcbjga+Xt72rvx6z+2b'
            +'/dmmj/KWjtH/Dv31rfg0z+m8HfMAgQuXLVsDCR4cKPDQQoYNHT6EGBEir1+8'
            +'LP6qeFFjRowWKXrM+JFiSJKLTJ5EedLRyVooV6aEueglSjY1bd7EmVPnTp0h'
            +'ee3a9TOoUI+8clk8WlRp0aRGefnihUbqVKpVrVZdc1UrGhgAAMBYw2bNWLJl'
            +'zZ5Fm5YswoQEDbo9WDCuwbdy5QqMa0viXr59D330WZGjRpCACYvcKNLko5iN'
            +'GzNGCbkxT8qVLbOxOFQpUI+alz7+zdXU6WeLU7NuRZ3aNNWuX9W+PosGdlm4'
            +'d+HipVuw7d3cbXET9Btc+CHBIouD9Gl85MXkgzEqemxypuPpjmlexp6d88/O'
            +'Sz0zVSqadFTV5a2e1toa7Gz27dfkrl0XfnyE9fMaHJ5/L8nDHZEPVook/5Kz'
            +'jrrqrJvppewWtKwzzYKC0DPxxguPKfOwulCrF7xazz0P07Jvt97os80u3+DT'
            +'L8WH+EOso+SM8w+xwkbCCCVIYKruwAJlSskRBn/cyTvuhESKwqaSEk8rNlJD'
            +'L8Op1PswyrNMrK+uEm+7j8r4VORyocQMC/C45jgSE7kdG5vlTBxNArLNm0YD'
            +'6jui5Bz+TbQJiyQvwyadfJLDmqQEFK/a2BLULYGsPDSvuXTrkkswvyzzuP4S'
            +'CywlSNJcUzo1rXPTzTXAc3Co7Yyk0EI+MXRSvT8BjZIt3eyay0reFsXtrYEa'
            +'VbFFFgHUddL+MpoOkhtVUlOyxXgkls1OgYSBziFF9QjJUkdbCo0lT0VtT9n6'
            +'dI1VKWGt0tX5CpXVVvxw1e9RMmeEccYB3bUo2Uwb05E6ZZf9sbvMMtsOQgeH'
            +'nFapMcZQTVuqmjS4SSi9/RCN3uQr91VXdSN3LnTThbSo4ng1bFflfpk3pgRF'
            +'PhNfILuDlt9pR+UlluREQ+MMg7Etb2GGPcTyyodpta/K3C7+zo+/GAkTrLnD'
            +'Og5w0x1zfKk6k3+Mkzt/i/J36qnxBLXIrbSdmU+bb25vNypFzHLcnH8GWjhJ'
            +'/zuaOV5jFNAje0meu8CnGdw3b6L0fVbvgPPcluYMVRULbPZsJXFQQeFbPFxG'
            +'0w6uxeXcHdrXdZersTFIpstx6ZOMDetu7Dy7mu9+S7dIl6Vg5vO0rlODsnDD'
            +'YbttxITEJhvxKw+CPPKNA2zbRaRfXKpH64aVt96YIBE9u88ilBrgvVEvdasz'
            +'BE9tw25jM0s29rzPaqxtxxqURMbp2lni22/tXSJFvNy4aIwiFf73oplTSiVH'
            +'9l9kWEeE7Z+wONc5AEqHf/0LHZD+4pCTBDKwJmPoG4VIR7S/VUQqMkPNGa53'
            +'wZitYYMbtMoHOai9PzTEECZcyAlVeIgTPqSFLZSIIWQoQxbO0IY3xGEOdWhD'
            +'QfTQhz8EYhCFOEQhUuxVtaJYrZSYxEM1USCh0WAUpeiGIcTsDFWU4vU0iIYh'
            +'bFGLWZQiEdDgEEa8TxFmPMT70ojGhSzijIooY0PQaMY31qIWtMBjHu+4R1rY'
            +'MY9/xKMf7TjIQQaykLQYRCESOYhFKrKRinRkISDJSEJMspGXhGQh/uCVErYv'
            +'hjsEZShFaQgiltKUpxyEE1W5Sla2spVgzGLMZAnLWNLSizF74xkPwYg09pKO'
            +'h0jEG9f+uBA1CvOXujyjHwG5TGYy847NXCYmF4nJTDJSktO8ZDYdOQhBmIGT'
            +'nvzkKMU5zlOW05w+TKUrVZkLdbbzUF78oC2tKMIvbtENX5ylBo2piGAK8xCQ'
            +'IGYuA2rGYA5Tl710oyL6CE2GOvOZDaXFNhMZSWxO85qPtGYkKTrRQWwSAH+A'
            +'IThNOE6SivKcJz2lO1WqUnbiApbznKc8b2lLKSKTmMN0yDGRSUee9rOXC4Fo'
            +'UPFoC2gSFZCTdCQipJlRRirVmk/lKFQn6c2PihQiJcXqDlG61SGu1Kvu1GJM'
            +'pWjFmObzpfiE5xp5elOA/jSgBlWrTQ36PqHWta5QZWRekSr+0adSdJt/RSpV'
            +'O2nVkWbVsDPkamJ/yMSvNvadaK0nPC8401jCNIpW3GlO5YhTnOqUp2y0a2gb'
            +'6leOInWpFy1tUjfa0W8StrCHNaxiZetY2jpRrGUVq0xzq8F7RvGXBdUlQPlp'
            +'U2T2s5jANGZcRbtcZmrUonrFaFSx6dzpdrO1rk0hbA8rW8XW1ru5oGxkaXlb'
            +'MO72DJ/1ZS73Gde4CnSui0DEUJk7X7xWU6pMjSoi/orfi3p0sNjV7na5u9V0'
            +'etexuijvFfNJ1t6G9azwDKsv4frZ4UoYrhLe6RkXMV8OR7Sv01SqJSVqWm1m'
            +'k5uCDSlhAxzbAW/VwLVNcGTNO0v+sop3rBn+50LaWtAc/3OfanSrHM2oTOYa'
            +'lRZGhmhUr0laaqZWuvt1pH+xy5AVZ7XFLn6xY20sT7PWcqyX1aJaOcuQgwrZ'
            +'n2gEqLDSmIhhdni++31uRjc6Z+gqWZGIEOyUs1tlkl4ZpVnWMo3r6QZBg/nL'
            +'hpZlTN8a5F9CAsjIvelB26peYhbVzQxtKlOpm1dOd7rOF0VtIfKsZz6X1M8n'
            +'BXRjZfpgCBv60FvEcVuFK9D3tZXMcr31Ti+9XBM/984hdvKSB6FfbTpy1FMu'
            +'dZ9Pbc5Uf9XVra5xWRMsbS0Wt4yyzuyjfzppRWB7jnTddWipa8kPr9bXnCa3'
            +'datK6mT+i3PZ5Sxws8EKU9yOt7Llza2YH1LMR3NbyJr9qULDbVc7W5TJ45bq'
            +'nBXp3xRbtd3ufndKs9zSdbJyxva+bG7Nu8VIa/vRwmSzrXv8cQoPHKJGRrjB'
            +'y01nETt1qtcF8MNNGnFTynulYO5yoVt9hgbTE63ZlvVc3Rt05BKd3xs2uVAr'
            +'aklgo9bli2z6kxt57JjLHJQ0NyVjbb7KZ8cSizSF7IJ9+1Y1ApeNHj+j0Sf8'
            +'vocmnaGAhXpFy43u6epVolJmt9W1inUibn3e97asgye7cVqqF8i0RrOOfwlw'
            +'fqfR7UFNKt3t/uFMkzbEoF4k1V2r96vzvat+V+erce5lsGv+/HoB92ku2Uzm'
            +'gI/ZuJNu8+MbunSVS3PEJt60qGG+ec7r0PNCjDfouQ5h08sYssav51oH6s9Z'
            +'H/6Mq3f0enMp+9HKGfdQnqiw+Xp71n604SLtve9/H0Thu9LBt6Q2GO9J1hpn'
            +'PIpzXaPIdbwQ4/Y71z3+6clFi+RmZjrOoDYtJiu4aVK3/+K98Luh8SO/8mMl'
            +'0hO9rlu1CKMwYkqznPKsXCO5M6K+t+MvJaszjFotAOQovEM2BExABVwsBlyl'
            +'jcu5LTur3FqrOZo/hog+zTqoClOzYtpAaCo457Iv2lOt+8q83VMxE+QhFPQh'
            +'FRw+noNAG8un3mo/yjooHguyGRz+ulurwoHKI/6zKy6EKDgTwMo7N8yrO91b'
            +'txI0QhniJiQUBCVUJUQ7NMLzsvabJeJavPVSK29DLzvcwf4LwWoStjGEOybT'
            +'vCJMQ0UypUB4Nzd0Ihfksi2KQrA7rzPbQ8MLMkNwL0t0vD5cJh/8tL4Kwckr'
            +'NkY6NjXiJTJiveNCxb0Yp0JABHFyRR2SJEUKBEXsIT+wxVokhEAgBCDiplrs'
            +'IWAMImBcwx5ixCaSxGSkKY2jMBmEP38iO7cyPIHjxD+iPU/bvg+EM7xKJMGa'
            +'xjMqo28UR8OLPug4I0OYxUJAx3RUx1nUL0lax3SMR1dkx3r0Az/Yg3vUxz7Y'
            +'xz7gRz/++Md8vMd/BMiCHMh9BEh+DI2FZMiGdMiHhMiIvCJlBKMuoqk0YIKJ'
            +'lCJplKsbjDREgD5nXLQ1CiQ9cqZmajtA4qOSzKN6hEd1jMdBkKFZjMeaZMd3'
            +'ZEePIoM84Mme9Mmf7Ek9AMqh5Emh/MmV2J8DkomkPJaRQUqmXATGcMqldIT5'
            +'CYZf8IX50Uqr3Mqu5EqsDIar5EpGIMuyNEtEgA5GSChwNMu2dMs3css9kMu5'
            +'pMu6tMu7xMu7hA6YMEeU2EtLGZa/tJG0QwlFMczDRMzEjAuh1AOjbEyfZMyi'
            +'ZMzGjMw8oEyjJEo9IAOvGIM4gIM3iIPQFM0FGk3SBM3SJM3+0GSD0IQD1GSD'
            +'O3oEIiMkO4rNh+Kj2hyk2jRJ2BwkYvDN3wTO4BTO4STO4TwlW1w2SvK0QSCE'
            +'5XTO53TO5TEJ5HGMbrMUv6ROk3AiI9pOJVofr7KFNzhNOSDP8ZQD0BTP0STP'
            +'0FxP9gxN8YTP+HwDORgDzkTN+8TP/NRPNojNR/DPWvDPABXQ/wTQ/hzQAaXN'
            +'2hTQWijOBnXQByWG5RQERppQbqJQdLpQCtVQDa3QvOohD/XQDt1QEe20DwXR'
            +'Ce3QCT2TA1EeG2mMYzwU8pTRGaXRGq3ROJDROThPHD1PGZ1P+rRP/RTSIb3P'
            +'AzXSI0XSJBVQCGXSJiUGFF1DELX+UBK1UCmt0A9NURG90iqN0i0dURI1US6F'
            +'0k3JTmTpn+mEiTKFUYGw0TZ10xvd0fL80fWsTwDoTCLFUyItUCXl0z4dUCcF'
            +'1AZN0RD9Uk4z0Sy1Ui2FUi+tUijl0BOV0ijNK0TAEaQMGaWpDoqrLU1VqTf1'
            +'1BnV0U+d0Tq90zw1VfzcUz9VVSUN1FYVzkfVUk87VA4dVC8NUzGFVUQl1C11'
            +'1AwVBE3B1ALZHJJZU1zoUVFF1k+dA1I91WZFzVWFVlZ11Wl9UkcF01m91Q2V'
            +'VEMdUULlUm+dUkO1Vm7lJnkx000xlgIp1mRtzzeNg1B9U2Z11nmNg2i1VyOl'
            +'1mmN1WL+tNISjVVdDdcptdUuhdSAJVcMVdEVXZMWNddFAD2ti9E3nYM5lYM5'
            +'mAMetdGLxdg2lVd6bdZ7BdkAzVdXzVBtvdUrPdSTDdNZjVSD3daB9VVFZSTP'
            +'UZqlWVd23Vh2pdGO9VhTDdmQHdlWXVmXbVRyBdeSLdoLHdhafdRtbdmZNZ7j'
            +'YVFg1ZGXuFnyhFc3zVpl5dgg7Vmf/dl7DdpAbdqARdFeddqTLVGCXdteHdd+'
            +'RdlvdYm5ddF5YViVuFqd1dud9dqvxdOwFduxdVKm7VYxlVlvPVu4fdmCbVRG'
            +'dVtOu1RNuRSF5RyUyNu9TVZ4jQOe9dshBVx7FdzBjVSWNVv+WhVX0zVZwx1d'
            +'a4XZQbXQmoVdul0ETlVCzM1cG+XcztXPz43W0G1SWD3Ywr1WowXesk3Zte1X'
            +'gS1aujnXqEyJdIXemLhczA3VrZWDd6VYILVT3f1b3l1V32VSLC1YhH1ZgEVa'
            +'XmXcLF1Uf01eThuZArnbM5le603WnHXT3OXeIvVeVQVfCP1XbcVV1Q1RXT1c'
            +'swXTAUbc0x0EBInfYJ1edt1a++3a7c1fId1f/u1fBz3f0Q3XxE1f131cgwXh'
            +'Qt3VXgXWTWngz9GUVaJdm7NdrKXR7M1Y/K3g0bxgP81gBx1a1uVgo0XbpCXf'
            +'pOVXogXg043ayq3ZdE2JB7bRN7D+XvYEVVGl4RoOzRvu0xxuUOMVYJYV36aN'
            +'W+Q1XSpFYLb14HJFENmNXctd0xqV4Ree4FKl4me1YmnFYuNM3wAuWfQl4Tzm'
            +'Yy9+3BEOWDSuG+eNDPldYxqlXzeu0Smm4jmm4zoOTgxdXG4d2m/NVqT14vFF'
            +'3QDW1ahVYjN930GWiRYuv1xQ5BxF1mXt2zi2YUdGUki2YwBe1EsGYplV2RAm'
            +'XCq1Vcdd4OZN40u12kO+3Yxt4xleZVauYlc+Ulh+VS3G1V0+2sU9YPEF4bdd'
            +'WdeF2hNuWHrZZukVZjeGYik+ZmRW5mVmZuA0YFne41um5E3+X1k933010WDV'
            +'ZoU9CSb+1tt3TVZGruFyxtdz/k09NlxAVuAN/tZnHmhZ3lcAVpN6SWE1hlGt'
            +'LWY3VmUKRuZW9uclBWjfbNs7tuZoHtf19eD1LVxyDQRGOukq7WZBfuj/uedv'
            +'Ztf5FE85pWkYXuRxZmV7TdXA3WhJFuOnXWgeVmAspWZJPdse6sVi/FA/aNlf'
            +'duqvojhSfiJ1Ks9QlenqnU8chc+JrdgelWknduLyPE94JdX0NGv0ROs4gE+1'
            +'Tmv5ZGu2Rus3mM25puu6tmu69s+N5mjo5OvnbE5O+2txrdDmJGzmNGxC6MXE'
            +'Zk5B6EXGZmzDZs7Adl8e2R//pEr+YcrMTsrNjsqZeIT/2Rz+R9AFXXgidlrI'
            +'0m4p0h5t1caF0c4F1saFW3jt2Xbt0aYD+bxt+dTtid1tsMZt3a7TGHCD4Sbu'
            +'4i5uNDDu5Fbu5UaE5nbu54bu6Jbu6Z5uX7Du68bu7Nbu7ebu7c7LuvTH7xbv'
            +'uuSDPQCE8wYE8wYEPEBv9l7v9D5v9XZv8zZv94Zv98Zv9D5vRNDv/UZv/vbv'
            +'/hZwAAfw/p6FA0fwBFfwBWfwBm9wO4DwCJfwCafwCrfwCo8BrxiBFeDwDl8B'
            +'FfBwDy+BEOdwECdxDzdxDgeCFWfxFl9xInDxGF/xIZDxGl9xEsDxHNfxHefx'
            +'HvfxHo8ii8wiIe+iIh9yWhJyKer+ohHn8BJg8ibv8C9YgSfn8C8YcSbH8ibX'
            +'giqXcik/gS8H8xNggTAn8zIH8xX48jE/ATQP8y8Icy2wci1w8jmn8zq38zq3'
            +'8ju38yzg8z738z8H9ED3cysQdD5vAg1XgURXdBRQ9ERPghRodEaP9EZXdEif'
            +'dBUYgkzX9E3ndCLg9E/PdE8H9U9HAiQwgVI39VI/9VRXdVR3dSS4gVKPdVS/'
            +'gVVf9Vk/vsAbK3oLO3lKgRTg8F8X9mFPASn/9RUg9mAXdmQ/dmI3dhOA9hOA'
            +'dhNgARaIdmk3gS+/9mnn9mnHdm//dhP4Ai0g93I393NH93RX93SvgnZ393eH'
            +'93iX93n+l/dDB4ARoHQVQAFLz/d+9/d/x/RRF/iBJ3hOd3Vbh3VZr3VVj3Vo'
            +'h3WHT3Von3VWN/VTb8Joo0jJAqNfB3Fi93gVOHaQ5/iOX3aPH3Zk93Zut3Zq'
            +'X/lud/lu13ZuD/d1p/mat3lyp/ec1/mdrwJ7x3eAB/qg7/eBp6KCN/pPJwJT'
            +'X/iKn3UTmHhWj/Wnb/VXp3hYHz3C6zJXI68v4niT9/qvB3uPf/mxJ/uyJ/ub'
            +'R/u0x3meZ/u293mhh3u4H3hRP/q6H4Kkf/Wmz/tVj/hbP/WGf/jAt/Vk1PXR'
            +'wzgwC/vEV3yTN/vGd/yXV/vIr/m2p/ydf3tK5/e413y75/z+uad6wG94vq96'
            +'vUd1p1d10+f7sGI/LyI0rcenGmt98UKDxaf9xX/82398ydd9dq/83q93RNf8'
            +'4B/6zif+Tj99wJ965I96iE/1paf6hC/1jC98woenrq/96xd73Nf+s9/97l97'
            +'3wf/dr984Sf/RC/+8w91iv97p4f4vy996J/6U0f49Y/+44sxJoREjUcrs8L+'
            +'/s/+7QcIEwIHEixoUKCWhAoXMmzo8OHDKhInUqxo8SLGi00AABih4iPIkCJH'
            +'kiwpcgjKlCpXsmzpsiURJDeQmEBi8yZOmzVr6rx5YybOmkBv1jxj9Cgao0mX'
            +'Im169CnUqEdTUK1q9SrWrFqzHuz+6vWrV4hix5JNmPEs2rRVNnY06fbt25cs'
            +'iRCRa5cl0ZkCfdIcahMoz8B8aRK+qVTqmaSIo6Jhmlgx1KRbJ1OerIIq2Mya'
            +'D5bt7Nms2tCi2XqEa/q0irsp6Z5RrTqnzL97iZrQK1Pwz745f+6MnHjx78PA'
            +'Dzs+U/k4cqublxdk0fUz9LGip6cljfq6ySSut7uOKXAoz8K1iYonXHvvd9hI'
            +'nP6G7Dv4U8hM5R89kvw+ZeYskjAPG/1/Q9QJiJF12BkIElV1cbfgS7Dl1lNQ'
            +'sfmlHk43zLZefL41JlyG7g1n1BGX4TfiVf2ZaJBzAKqokEVUDEhdgQceiIKC'
            +'DNqokl7+44UX23iwfVebhX+Rl5MJj2UIn1QbBqeYkhsyaRSJUSp3IpUCJbHi'
            +'Z1sw9CKXEsUoI3ZH3DhmSjsSZuGOQp1HIU08BemmTe8puSSSxH34lJR5Vqkf'
            +'QUhg6dkXW3b54pdgXkfmgmfUOCSR4/m1U2y02UZknB42KZyHTj35pHBf5Bnl'
            +'nlX+CeCghHJUmqHYIcodXSkRadujPYEH56tBEmbnnXS68aGHn4LalXOh+jcq'
            +'dKUOWGiqpq26XY0x0daTYA6e2eZOD0KqV4fvNcVpZI4VZ5yvIwoLFrUEERud'
            +'sQIim2xcKQExJl01ykWXTUkIyaNMtqlppo/9FjknpgEnySH+Yht+KiJ+434V'
            +'bEHnFpvudOuya9KyDDorVGGABfnog4VRGiGuBS+WKXtQhXsVwlsp3J/Dn0Ec'
            +'8akTo1bxgs5CiKaPOEPIY46RvomhhiTDx217SC2l2MkJr7xcy569PFrMMitb'
            +'MRGtuaYbpbbmRV5g0UI4nlS7MrZp0fN9mPR9mzE8btOdPR2axFKfRDN3FV4Y'
            +'lJkYhwcUb7flJDDguT4l9rZoJ7c0022T9bZacZu0gqF0cwcpxrJGeLNegInH'
            +'d5why1lytnQG94WnhueHuGaKL844Wo7L/ZHk2/mYppuT7nwveBCKXLTIjX0L'
            +'+hko2Gf6ZKinrrpYrLce9eslsRD++9W06sT5bDrytdO+G/OEpLfcm717kh8R'
            +'X7zxYCGfvPIYUeG63GJCb1dMgKl5u8d+1z8hbNvuLrR79C2JRhpUULrxcaV8'
            +'XzkfRNKHETCwD3Iye99LFCQr25HHWl+LVV7CI7ojEexzdOKWACsTopRJSQUG'
            +'RBF/TKCQI0QnUKRSCximMB0quIhAMUMBDnOIw4/oUAU77OEPfehDFAixhxCM'
            +'4BAuJ5se1e9eZwrP3W7Fod/5j2jgM4r4qHKZLWYxCSMUURazSBUUpGCLZQSj'
            +'CQtygvLpRIUJYaEW4AhHhQSKdHX8whFcmJBAzfGNCznCESYiQ/VNAQzTiWFF'
            +'BrkWjmD+IhShGIUjIynJSVKykpaMpB1JpwU75lGTWkhB6RKiJVB2Eo+ctGNC'
            +'qEK6FOiwla58JSxzyIJYIvAhqlDFJ0ahilHoEpe7/IQve6nLUXwCmMTUpTF3'
            +'qUxiJrMUznxmKUwBzWlSs5rWhCYnigmKbYJil57whDa56QlQfAKc3PwEN7cJ'
            +'znKW05zo5GYr4tkKVshznvW8Zzzpic988nOfHGDkJQMqUIFmko8F9dQeFZIC'
            +'Oh70oFTZI+liKdGJUlQFtWzIF3j5S2Myc5caLSYuc6lMYOYSmSIt5jBxOYpr'
            +'srSlLuUEOD0xinSKk6agMKdNz8nOdeZ0n/d0BSzoqc976nP+qD6VJyv+CYBG'
            +'DrSpTg1FQ6Mq1ami8qAUvSpFk9DKizbEmCRF6S2P6VVeejWsICWrRzk6TJey'
            +'ta3QRGdMd7rTcRbznXHd6TZHEde9shMU9uSnUffJiijUMxNHRepfO8ARSTy1'
            +'sQGlKmQjG1WsUharXGVISTca0lyS1KS/VKlIkanSW341rG49rUu3ic52kjOu'
            +'qv0mXWPKV3X2Va7lPCxiifpXn7IisPJUKlMdK1xJSra4xa1sK2eJ3Bzq8bKk'
            +'BeYvRdvLtBKTtJutq1dPStZPoLa71kwnT90p13XeVbbvLCc51fnN1eLTt7qN'
            +'ZxSMWtTDukIDAB0ufqFq3P1Odbn+sjyCf1Fw2YVU95hmNWlHSUtWjaYUmZ7d'
            +'rHdP4V1oprOdoUDveGur2mK6M6Y3XSeHb+ve3fKWsP3krTxhAdz84pe/Lm5o'
            +'gGOMwwErZLQhBS11Hezgzg6zutH1ZTEn7F1OPHOu77xphj0MYriSt51MlmsU'
            +'DFvPoQ62qPGdZ3xNPOX23nPFLBbui8NsRxkH2KLQ2UJzAcRMznIWx88lKZBv'
            +'uVnQFrik3BUyak/BCT23lp11XS9fzWne15b3tawdrGALm0/CXlmoJ07Fif/q'
            +'5S83VsxivuoRlEvmHNI4IcvUcTCjm1lm8rLAwewsnFWB5zxzotVIDrST/xzi'
            +'JgO6ybT+5WmWR+zTK+dWnlHQMj4nTWmnWjrMWNX0pgXc6ZOKNKQItm5de8ns'
            +'j4o2s6petVtb7eok+3mcN721k5s8a0Ojt8q/hnSvp5zro2ZCy4EV9rAHWuwX'
            +'J3u5ab5oWKvL0boG89kohW5HAb7mIGO7u97u817FDeJX0zrEeq2pX3ELWF4v'
            +'+rC95XV87bvUeD913i6uN3I7rYWAf/TAcNaoRxUcWs06GJctlTBbYd5W8GY4'
            +'3BwONDn76uF0hmKbJ5ZvPSl+cURLWdf2hDfHL+lx/oK8siLf8WdPHtrsshm6'
            +'zgarZgve3W8jfLXrtXmGzznO9YKXm1RGcSsajWiJpxvpSa/+5NL323SsmpnG'
            +'IB1tSUu+5pb3G6zWFua1te5WmnodyehFOF+PXGhQ6PXI6S7xYCn++KO6/e2T'
            +'jLtx527Zc90bImnNri9tzO8Cbzfl+x614E/rWnHC1eYJH+dMaUtbvLaWy1KG'
            +'vK7nG+z7Wl7pmJes5q/qMC11ZtQjXTBnTX1SOevdpM0OfOpd6mfCpxfh5B67'
            +'Tf3czrgafctI/bWj85n7eVa+9478fWRZGfyJivy5c7ZuWOO/9+tudN/OFrLM'
            +'T9tqQad31q7vtpPF3qv11YXFVKQhFpVdmYm5W2CNWPmZH/pBlhbImApo1XK1'
            +'X4+d3nb928phXUet2UjlUvSxVSr+YFit2ZZrASBrGZqHyRXa3VOu6R5uhV9S'
            +'8Z75UVIEQtb6JVcPiVzyJR+oJVO/pdRZkdrogRSRvVz0KZ56yZ55yRT2cZ2g'
            +'zRpfAd2Idd/EqdvR2eANElcO9tcOwlLdXdYXyFnozVm0/RuQFWGohVpoJaFb'
            +'5d+E0dRM8VJNASA38ZJM3SGgYZcBsh2JkZhvJeBQeQAXduH5faFUhSEtdZpY'
            +'PWIyNdgwjRV2tVl0ld4IloIcUlMeotcU+t/h7SH1lZcJfgKXeR8gvtfubRwi'
            +'Xp4iThYjvlL7NRstOtt1aVf8KROdwR8vZWJqqReTdZ2tgRdOyRQetpbPjV+i'
            +'hV8grlv+PT1g770iLCIXC3yBjPkgtamVvk0XWm0Xg/kYdsUfHPpiNalTegma'
            +'ko2XOMVew/VhXKFiogHi0PkUNCadKOiXNBZUgCHbBS5b/C1fZ/0YnJUWv9mZ'
            +'R3XUOJLjNAlgbOVch+GVANLUQyZZIMZT0Xnf7SEgfFkh+R2i+YnCKIhCPlpV'
            +'LLrSLFLinH3ggpXeJCrfQI6CniWkQnIC1/kfec1WTrljrN2cKR5gPwEdPGIZ'
            +'M/JTPcZbSI7CSOpjSW6VI5YadBkf1cVZCEqbgaHaJ7TaJpIjTYpdbX3d6h3c'
            +'TTETzh3cbaUiFn5fla1icLWiI5VSJm0SVaXSQt0R8E0UPyb+mw++2VlVYuiF'
            +'Iwee2lf5nUJeUzidk06tnjnaIfUZprexEz65wuQFZUXSo0feoCjkEShlUmbS'
            +'ZUEtFESpUlyCUnLx412iwAroEAsg2wqUJqc5TOc5xF4mU0Gy2Udhl/Mxm2wS'
            +'XCa22ncxngAKoFwxnk2NAimA5ZFxGFn9oVEBWyr6FGTikyFunCjcoyNNZ3Xe'
            +'o3WGAnZWp3ZGEnVm5ySRQogAkgUCmA8lgRABGAsAGAokgfqBBHvq0Gl60Q6d'
            +'5xfsRxJUYxIkwRfkZ3/m537uhwmkZoD+p3+aQH/eZ4Dup3taxReQUFZcxoOm'
            +'ACBVBgmZIYaaYTdlKId2KIeaAoj+hqiIjiiJlmiInoKJhmibERMpXF2LDmHp'
            +'LZM2mlqLFpMr3Chk4qiOtgKO8uiO7mg83aiP6miOuoJSVYJeJSkx5VVYGmNM'
            +'JWk7KWkuMd44hYInWCkvvcImdMImbCmXfmknhCmXbqmXiukrjKmYfqkpvAIs'
            +'lOmXIgACJECcyqmcwmmcwmmd2ime3mme6mkC1CmgvoKgwoKgFqqhEmqhIqqg'
            +'skJQGaqjPiorOCorbEJvvUKkWiqlFuqlXiqkcmqk9hanboIDjCqplqqpniqq'
            +'piqqWgCrtqqrvmoFvKqsziqrxmqsuuoG5OoGVMAGYIKu/mquogKv6uokAOuv'
            +'DuuvFmv+rl7AYqkXbJHdt20fbG3fzT3rt43dOHmotm4rh26oGXIEuIaruI4r'
            +'uZZruZKCKJCCuqKrumqnuqYrvK4ruk7SdK5rutqrJInCr0XBFeyrv/6rv/br'
            +'vvarwAYswP6aAAjAABBAwg6AwzLswiosxCqsABCAw1KsxFbsAGjsxnZswjYA'
            +'yDbAA4QsyVIAyYbsyJ6syKrsyaZsA1TABFAAzFLABMDsBNxsBeSszu7sztLs'
            +'zfosz+ZszU5AAzTrzrUWbH1YedUaoHHdtX6YKrwoKRhYL01tCL4oyukSKQDc'
            +'i1pXj5kr2Iat2AJAvU6n2Z4t2qat2q5t2h6s274t3L6tw87+Ld3Wrd3eLd7i'
            +'7QPsLd/2rd/+LeAGbt9SAN8GreEeLuImrs4WLQBIQmxNq7QO4LMa2c7B1kyt'
            +'V4ty4zJtrtbKH+cqE9ZG4i6NLemWLtmyLeqmrurqa9y2rusCbN7GruzO7gAI'
            +'buA2AOHaru4WruL2ru8G7QMYrVdC7thRK7XWmtN+WDuB7uc2mC5mbvM+r+fq'
            +'kulWL9iuLvZm73S+Lve+Lu1+L/jW7u72LcqOr+3+Lvr+bvACQCWMnZUy7QoO'
            +'r2zJ1sN528P5ZvM6r/N+btRCb49xrvUG8LhqLwGnbvceMNyGrwLHrsiarwOP'
            +'b62mrwQb7vpKQvK+3uVK63jJ1rX+fpN6RW/URi9xbm7X7q/zCjAKc0QBr3Da'
            +'ngLApt3rugIC/9oCy67Czq7gNvADP7CtTrAP62wFq9P9Fu/xjp1e9SFrYZ8S'
            +'yxQI+28Id66clfDm8m8KozALX7HZzrDrwrDb1q3F1rAC364O77D5/rAZ52wQ'
            +'J60HPys6euL8TqsRKzHjRW/XNrHVRq3zqivnjkIVCzDbnsLanoJ2YjHrarEh'
            +'gzEiO2zg5i4ZO/AZm3EFrzEU7pU47aEGdxsoWCmVett6iXD/5qITYy0e62Lz'
            +'9nEAE7LZArL2GjIrJzIiNzIs++0j//D6VoI2eXCUYiu2Kq+0WuuHqZdGhfIU'
            +'h3CLinL+1ZrhMIky9Jqy9aJyIBswK2sx7d4w3VJzDccyNj/ALE/wBERyOk5u'
            +'bF0yOOeSB/9y8UJvCHuuEzPYLWWuHvOv1X4CM1dvC6euKhNyNEuzK19zNsPy'
            +'Nk9wBScx8cKx/N4kOpojWX5aO6fU9MafKEcx80rxPJuuM69wPs/wPt+tNd9t'
            +'P/vzP6dvECPt/Oay/G6wJN/ct9FxWBUzRNMxOltt15LCRJduRRdwwV6092a0'
            +'Ao9xR5fxR6NvGtda/T4hQY90USuZ/krvMrF0UjNfOi/1Lc006d4zFlP16uL0'
            +'AX+xTn9vT5PxTwP1YhWvayHxE84VFJo12TFxU2cuQ+cxVKf+lDCrglSPbU0T'
            +'MFZ371aHb1fv8Ferb1gzXDm/cbiN80lXa1h+7kP/b1JDMUNPsUzPddjWdT2v'
            +'7V1zb16D717zcF/3bhpL7iQP9ga7HhuXk1618y69s0IDHmObdh4bs1xD9vVK'
            +'NvZWtttyMQ0j8kZjdmb79GYnbiR3cLgp7ZMSNFpTofLmYjuj8/9KLTE39HQx'
            +'NWzHtmyrLlbbdtxeNlfv9vj2tuIGtUETcbV+t1du3ybPsWujNkO79mq7dUpF'
            +'t7lmr1Xj8wvT9r9edm5ztHbvLnf7drNq8kALt5KN92gr8RE/8TDrMRQbeHp7'
            +'8jC5d7mqbnw7M323bt7et07nt37+7/fhhjR5/bI5mvS0/nIoDvZim3BqM3gp'
            +'O/gATzd1T3gCY/fsQgCGn6+GGy7jti8bc7KOj/afBXb8mhc7t/Vb62JSr/Pn'
            +'qviKszjquviLw3jszjiN1zjPQgBHtC/r3ZQmX2twwjFCT7I7OndTKzaKt/Vj'
            +'Izm4Kjk047R1y62TPzmUB66UA6/RVrI5Czd5zy8wDi9thTkJK/eYQ/Vrm7kK'
            +'oznbMjmbt7nezjhP826cA3FYR6Hy1uSdK28UHlyIq9ZI7bHnLvSfC7mgn7kz'
            +'p4JdG/rBInre/i0EgOzIuuwYp/qi8y3Jwnmj56wF3PgQM1yX45Tk1hQnk3P/'
            +'TaITp1z+MMuZ6Da2/jb4p58uKg9y9jIaAq+5ZZs6fpNvA6t6A6Q6tb/63qY6'
            +'tpPv3s46rd94tl4CMF0CLnXTJYDCJZj7Npk7dKU7uqu7uauCuae7vXsrt+a7'
            +'vkd1snun2Q5ydwI8d16SvOYrdt7jAv5r2lk3tDu7v8qww/+aKxAAxVP8wlb8'
            +'xVe8xlvsxnc8x2v8xcv4tl87yXM7yHK7yV/7A4j8tbs6ybe8yIr8zc48zde8'
            +'zd88zuM8lQOABmSCz/88Kvy80A+9zwc90R/90HfpmJJplzI9mp6plja91Atq'
            +'JxSqmSp91f+p1mv9nG69129913/9188pPWUCqIKq2YNqlBn+Vm+xfW+1Atun'
            +'vSuEwNnPEyuYfSuAARZYAd/3vRVMgd8HPt/vvRVIgeD3vRQAPuH3PQM0vuNn'
            +'gONHvuSDgAI0vgKAgORLPuRnPgZ0vud/fgZ8PgaE/uiLvueT/umXvulrAOu3'
            +'vuu/PuyzPgjEPu27fgZwRAsUge7vPu8XwRDovhqowe7/vu8XgfDzfvDzPvHr'
            +'/k/kRvM3v1DMBAnoxPSbAAnsxPQjwfXbxPY/v/YjQQ+Ef/jzgPiXP/mXfw+c'
            +'P/qn//nzwA60P/kbQQ8IQQ4IgQ3cP/7nv/7nfxEIgf3vP0DYEDiQoEATSHgg'
            +'SWKCYUOHDZGweOgQCUWJExtl1Lj+kWNHjx89ChE5kmRJkydRosyBg0cOlz1y'
            +'7GiJw+XLmjRdtqyps+ZKlzh30AAAYAYRo0SGDDGaNOnRo0qbOlWKlOnSqhUn'
            +'PmSBNSISrlgZggU70atMHmfRpk27w6zas23RwuXRo4cOu3fx5tVr18hev3lZ'
            +'sDgSEUVgw4clIla8mPGiRYwcK1IUmfJjx4wmO7aseZHkzpkhW2ZkhHRp06R1'
            +'kBZymrURIaldr25NWiZblm9xyGW7AyHa3LzdvlWLQyiAFlKXJneKfHnz5kqz'
            +'Rnd4UXr1sL2DI5GbMDvb4MH/hhc/3i5j8+fRI56sCDJkz+s7i5Y8OTQj95rp'
            +'X16vaHb+f/99/zMNh9/Wss0t79Qy8Du1invBOeaWm+rBCY2yzsILw2IoMO0W'
            +'5AHBDj38EETySCyxvPRQTNGw+R7z7LP52Attvxjbm5G++yYLUMcdT9vtNtxE'
            +'fGu7IBckbqjjKEzyKSWPwtBJDFkwS0QiQXQrN/BMzDI8FblMzz0YwfysxRkj'
            +'YxFMzMDkj8c1Z/PBLh9A3OHHKuk8qzgkmcxTSeqe7JMsKbHzMNA6D5zzLC0R'
            +'3avLRRdDgT34KDPTMjPRjO89MTNbj81NT/PBUzgXlNM3Qs8yNK07I9QzVeUe'
            +'HMtPE/h0cjtSqRwx0VtPZFTXwMpM01f2IsPsxTQt1W80Tjn+ddNTHUoF0VRS'
            +'3UL1OQhZZVJCo2Kd7sKI/BwUWuCgxRXXXcmFsdhMMX1R3f0wDXMRZJPVYVlo'
            +'6Q0uqCOnuvbaJVV17lVYs8pWunq/e9ZecW8ld9f34DO34WEZzlRSM+Gt2Agr'
            +'dxO1Q5kGPEuJDm9z4ch+J9x3wn+lc1W6WeutNUGEE1VYV4fN/LWyL9Vd90WL'
            +'4f1OTpeFS8vbjj20c2STrSWZCJSZNoFlguuEGVGZGbXR3GLdQ9NqG+OrVE2e'
            +'Nz3rho+DvjJUg0GUVmlqkTq56VdP0BhqQm84VOosqV502HRpdnFiFiHuDDOw'
            +'OS31NrM9VMJb3HhA+zu11yZZ5bf+L5RzwFm1e5pQHMi+G++8uWQXUkvD1Drn'
            +'zPaGj/CwW96tXsgf1DdybMmi3LodlHC86CJ1V8tzE0FXEQWIJ0MkzIbJPLNm'
            +'hldnk+DcECf1TqRVzZdJ2/s8YW6ofy8xouBRHFPidh/uu+8yIWt+zeeB7hBy'
            +'6lOFP0nsn9R++3q7JxGFwsBHz+vN/na11KXuUZ9RH48IpqBvoUp+1Zod/Z7U'
            +'Fs3NjTdmyx95+peeFQTwUh38W6Q6uLMD6ghqN2CJAqtkJOPMDn7UgyCU0hK9'
            +'7WEnY3a74JYyeJ4TkI5hgePgfO6jNXONkIT14lypXEcnFeKJbbNrzgsxNBxC'
            +'La5Av1H+0A3Fk8PzOGpiBIzYpfh2LsERMUCMM6Lc6AQ7J14PihZK0MbSQrZQ'
            +'ISiJWMShFhmztQ8CDk1fOp67yPgfISWwfQw60g/61cI9tdE6tOpdXKxkQxL1'
            +'BWZ4NI+7bGaznBFvWIH0z88m6KHL0co7bEFCg5K2RqNMTlsvJBXRCraWBdnx'
            +'L5bMI/Lic64QToprPdSUJ2fjoyrVkFAfYosaVcm2t/FJYFnxjRzvZyta6sWW'
            +'i/FiF79IrOUF613AbE3jDGYqNMbQVJlri7QamMyl+WkrEHmV4R4ZQ4JNU1HV'
            +'VI/EPHg1h/GwfJJpjze/SSQcjO1AoOxdxoCDTHX661+sxJD+DBvXviFZbjgI'
            +'oqde+GfPwBzCYfZ5jIxs5kfyfRE2AC3NgAgUTXlGa2QLVRIjbydB32hunBEN'
            +'0hUviheNGgYJh+DhZQInRhYJ8WGWMmmPrOibeP7IULNaopLSqSqYVsdgQCOS'
            +'bcR5m5zqdKcoSMHxPlqZfX5xpJ9B01EFlFKPxROadVJoyZw4VenkwGe6E6ec'
            +'2hoiSeYUMRlljF8ZpQIW+E1wH/UnCP0JONHVyG9oLQ0xQRYcWMrycS3dFyKP'
            +'gllVnsAEnGUIZ0H7WdE2JLSi9WxpOzvaHjSuWeDkWMc4ZjlRXQ6lP6Mt9PZ6'
            +'UcSc4AQoQMIRTmCY4KIguCrobXD+WYDc5AYGBYI9LnFPgIQdLtY+1bWPpPwo'
            +'RI9a12umKSlqYPNd7wKoLz4Arw5qwJrUEO1wFIUeS6BX0/cablSNK84fUFcZ'
            +'0gm1qH6D1GR2EWABCzgXAyawgRE84AInOMC/+AUvHPxgB0M4whO2MIUrbGEJ'
            +'Z5jCfOBDHjwc4hCDWMQlFjGJTZxiPfBhGC128YthHIwXy7jFwhAGjIchYxvj'
            +'eBh+8HEgfvzjQAwZyH4ocpCJbGQjC0LISfaxj20RZSlHmRZTrrItroxlKVf5'
            +'ylmespWjPIhBCGLMZBaEmc885jKL+cxmVjOaxcxmNYvZD2YYCn7xk2fO7HnP'
            +'qCtqLh3+w2BBD5rQCM7woRGdaEUn2sN9SPGjH+1oSKfYxTfmsY0xbelh7HjH'
            +'OM60plt85CePeshBHrWpT01qUUN5y1/WsqtbDesve1nKcYYzmW2N6zKnec5p'
            +'xjWagT0IOwPgD2XS737Ll+f8Ano9hXb2sw28aGlPe9GTtva1rV3jTsP405Xu'
            +'Nre/vekepxrVq061uZ+MbirLGszshjWtW/1rW7NZ13Putbx7LWd7D/sPjgC0'
            +'npVdrIDnV3TQNrizqZ1whf8C2w13uId5HPEX35jTFLf4pys+bnKne+MdJ/XG'
            +'X+1uWcPb1SS3Ra71vWZ783reKef1rwXB7z77+d98dhGz+Rz+6IPvnMEL93m1'
            +'Hx70SUtc4hg3urYx3mKPG3kPS0f3qYFcaj+8O8vwpoXJsf5le+d73ixfM769'
            +'Lu+Y31ngkRJqzWkOwvjwnO3R/vnbMyx0uVOa6EXX9qYxjXSjCwPqff9x0z3+'
            +'9FSvW+SFn/W7pezmNyue8VtX+ePpzWaZ4wdwnEm7sfW7bM20nfO7gPvnHTx3'
            +'0YcY1HWfeLe3vfcdo9rUR5Z61JW89HMbPtYjpz2W9V1vfOdb8ZBvc5zVzG/N'
            +'W77mm9SzpCLT+baD/vOjH/22Te/tpNs4GNO3tOyLLPjAN13Ut/d+yMEf5sbz'
            +'vuW6rvebUS55sqtd83/O5eX1rHz+tjMf7s4XvbijD25xqz7TeNe47APv3IRs'
            +'8NoNy7yMy9itywwv94AP7Mjv67quAceM3x5h+JAN5zIP4FBH/niO/t7O/uYO'
            +'+kwv4yrO+mAM3bQPADluBQnP+0yu5GAt7H4v/STQ/FaO/Cbvv4rv2PqL+MSE'
            +'A3fOA38OBOVOBOuO//Du6F5MBcut41Jw6r6vAGsP8cIs8oDv8XzNBrWw/MpM'
            +'5pZtdMrO/Qju34Dw4HpBCBeOCIUOCfOv6PYO+2JPAAOQAKPQ3azO1c4P8hjQ'
            +'5RzQ/MwsB8Ukz0IjDDWw+CSjDA0Ow9Bw2tQw6Pwv6dow4izN4jaNCTcO8MhN'
            +'8F5QAe3+kPayjN5kkOXEbuvOr/fETPj67N9uTqyID5fgAxGhbREVrhEfLgkh'
            +'MRI97Q0tsdxcTwVn7Q5bkBOpENZIMeVWrvcYbwYZLxAmr+zMzhl7Jef4DBaf'
            +'TRYTjhYdjg1xkduS0P82DgUzcRf/YArrsBO1jvfGzwbRz/G47sz4zd/UDuCe'
            +'cR5Fx1KoEeGskRGxEdvyLty2ceIekeJYbw7nsBeDrBw9kd1g7gq/zuvkTB25'
            +'MPjW7wtVMRAtch6n8R4JLR/1cR+tDfVK7x/1Dum+8eMGcBfp0PbArOpgMAGr'
            +'rBjZMfK2cNdGUSKJjfgG8dgwMudEB8A0ctA4Uto88touLu/+RBLcQM3GMlHw'
            +'MDEcZW8YzbH2XjDx0JH8anIdI1L9btIQaa798us+pPEngTIoFW0oP3L/QvIo'
            +'0bLGKjHV9kDwss8kfTHrWrAO4W0P8fIGZxLscA0Vj0/gwPAiV5FdFkEsBY0s'
            +'y9IsIY0ttfEfKVEp43AFnXIyOc71WvL7pvLw7q0hHzL3HNAKda8Z0UUn41En'
            +'h08RDLPnEBPRFHMxbbH6btExi3IXn3AO65IKZ+H2ptIYGVId93LMEMEPxO4P'
            +'76wC/5KXdpCwunIDU9PQVvPQWvPR2NIW/XEbjU4uLbE2Ty0qVVIKX43WXu4B'
            +'f2/82lECbbLYWFEala0r5ZEymtP+OZ+zwqLTxPpgJEswLdvwMfkOALVTMskN'
            +'IckRKquwPB2PL3lT5dDMC2/uC1eRJy2vQQvzPQcsPuNuPktM74pSLU9P3Aoy'
            +'LgfSCVOyJeny8MjxylzuRNdRFB8yHSdw/XiwIl0x4AZOQieUQiPMQi+0G/dO'
            +'Q22xx56wNrUT/DIzM2kvPGtyBh8wAiNw7LZyDDEQGtEO4GhUwGz0RnE0xKiz'
            +'H41SLSfx/+QwEJqyMuWw4wSURKPQy5S0M68wD5EUFM/PL2/GGceQ4OZ07abU'
            +'86qU4a7Uw/oPLbeUS/NuTLEPTD+UTIe08A6w8LBSRRcSAlGOTbuwOPEDEtJO'
            +'ESh1ES7+NRVRh1IhIVMnAxLuFE9/IRiCIcKAIcNKdVRRdVUrLFUjrFQnTdJo'
            +'sQ/6oE/57z5vVfWYDDsDcNVqMwFFjki9sw/ZjBCO0c1wzVgZ0lhD884cwRE6'
            +'FVqhNVoh4VmttVo7NVunNVuxlVqftVODoRfEtRcgbFzN9VzRNV3NNVzRVRhI'
            +'FRiA4V3d9ReAwV1JNRjqNV7lVV/xVRj4NV/vFV9pdWAJtmAHlg8MNmEVtmBz'
            +'tWEdNtMGQTiJbGIptmIt9mKJ7MyGTBc4tmM99mNBNmRFVmSNlRBM1mQH4WRV'
            +'VmVTlhAKoWUJ4RBW1mQNoWVhdthiAA90dmd5tmd99meBtmf+xUAWZGFoiVYW'
            +'ZuFolVZpjXZpl7ZpmZZoxWBoqbZqp9Zqi7ZopzZrr5Zrt/Zqq5YN1oANyLZs'
            +'12BsyzZt1ZZs0TZtz3Zsz1Zt1yAW6LZu7fZu8TZv9TZv9aBv/fZvATdwAZcP'
            +'BLdw9SAMEDcM7CBxEfcOGPdxEXdxIddxIZdxF9cN7uAOMHdzNTdziSBzQRdz'
            +'M1d0NfdzQXd0TXd0MzcGjgYImIIpXPd1X9d1gSB2kyJ2bZd2X1cKeFcKrqB3'
            +'saB3hZd3reB3h5d4h/cKrMAKhBcLrAALuKALuoALqLd6q6AKpncLqjd6t2B6'
            +'o1d6t7cLtJd6wfd7vaAKziB9hyD+fdX3DJigfdf3DOJ3feNXftv3fuE3fTVB'
            +'E0qhf/1XEzihf/fXf09hfzWhgA3Yf0uBf0/BFAa4gU9hgTVhDuaADij4DSj4'
            +'gjN4DjB4gznYgzW4gz1YDuZADm7ghD3rhJGABBTiBrwCCQaEBG4gQ07YhFR4'
            +'hXHgIAbqhEngIEyANHzgB8xLXlLjU8zriIH4iD/FCIy4iZW4L2ZgKF5Adqm4'
            +'iq34iql4ebV4i593ebHAebk4jMV4jJd3e834jNG4ess3jb23etn3jeu3ft94'
            +'jt93ju0YjuW3FAK4FDpBjznhj/u3E/54kPt3kA2ZkA85kTkBhBm5kR35kTMY'
            +'B7wiIV7+uJIt+YVNCCEueZM1eZKR4FPCwIlFeZRJmZSj2DiwOJVV2Yq3+IvJ'
            +'2ItfGYy7eJbDOI1t2Zbb+Jbd2H7vGI/vOA18uY55eY71uJAP2ZiPWZGVWZkh'
            +'uZmdmZEp2ZNfmJK5wysUh5OluZo3+VOCoJS9+ZubWAdaAF9WuSnKGYtpWYtl'
            +'WYulQJbB2HndmYzXWZfpuZ7NWHrnWI57GX/5uZfleJkBOqAFepGfuaCd+ZKj'
            +'uZKjOZoleZotuaET+oXBeaIp2gfGGZXPOaOv+JXTmYvXWYw/movteaTp+Xr1'
            +'mZ/jOJ/3eZjteKBd+qUJ2qBlupGz2aGxWaFxupIbupMRwlP+hNibf7qiSbkG'
            +'yFmjzdmoYZmj5VmpO5qknfqWV5p9k0Kq93l+qzp9YTqrAXqmuRqEOXmhbRqn'
            +'qfmmpXmiu1moRTkIupmoAWCKr5gqjBqdl7qjQzqd3zmMnfep9fqM+/mk/Xml'
            +'/RqrtXqwD7mrDZuCI9qSE7s3ENqhFzqi0TqynfiiWyCuLTspmHquW5mjwXiv'
            +'PZt6VfqNhXmYA/uv49iPCZuwD9uwc5qsXVuxeXqSJduIg3qihUBkMPqyjfqu'
            +'k5quQXqM13meP/upu6AK9FmOgTmq7VeOS1uwU1u1V7uZ9cCrG1uTEzqxFzu2'
            +'pfmTZzuySYOyrUK3z7m3ebu3M1v+qYd7r5U7fZkguZU7DUY7tJ87taObq6v7'
            +'vpHgmmF7k/Vbtrs7soOArd1avM+ZCM7bo8l7s81bi9Nbr32ZtO04fuEbwqm6'
            +'l+cbuuvboK2Zp6s5orGbw7c7tsH5rP/bU7qZsglco39bnRU8s3lblhv8qdd7'
            +'vZubft/4wgc7w2Xaul87uz8cm0u8oo0gCG67qFN8lVk8lhE8wZUaemPcns8X'
            +'f1M6tFk6wgEbx7VaxzV8v6/bphc7u7PZB0g8yEtZrY3glAf8yFX5wJO8zZdc'
            +'jJ+cpO+4ueecqqe8pbEcprW8oH88xHO6y/s7rJHgB2qbzL0ZxdUcyWk5nt28'
            +'0TvazeP+fKT7+cHvfMbft37zXM/3/KAnGcx5/KtB/ZINnaKLPLcT/XXl93XZ'
            +'XMkdXaQjvZ6p3NIrnMYz/aU3/aA9Xaxd+yxumgdGHJwLnZSD4JQr+9SrAipe'
            +'l9EXHZ4fndUZ/dXr2a9tXMppfNZvvNYH+tYhWQ8ae6z7HMQ3WZu5e8THfLbP'
            +'3MiNvYpbua5nWdl9e8GfF9rpecbrPNb/+gywPdu1/ZG1W9AF/cv93JMrWq2D'
            +'/KLTPN2zWLNXHbgZXN6hGo4lHH/j29orfY7zXaD3nd9hO7H728P73ZMTWqjL'
            +'XbKnB+FZ2a5XfNHxOslD2uHT2Au4YNInHpgrnsqnXX4vPqD+M96RN56sPT7U'
            +'xX3UvZnEEd3kE57Vm9zFrcDl0TjKr5re6dzic36Zd76Rxxq/f167Pd3XhR6c'
            +'iT28jR6zl5zdV77Z2Z3p0/i4Kf7e6V1/AXjqE7nqGbnfwXq7s97feRqtR16o'
            +'xVmKqRiu073VWV7py37p0Z6vH/zp/bni6xeZ4X6Q5Z66QT7U93vydb2SPyXY'
            +'h3622brYEx3wj57NmT2pyd7VD397+9raE/+ka97xHz+mI5+Cd/q1w721bd8r'
            +'hD6o995Tij6jQf91f192373wCT+4Df/0ybftWX/G9fn14z72M7jyuxzc/z3E'
            +'ozmtDZ3gmxjNfT+ViyD4VT3pBd/+zc8e+XfZyhUfsFfa+QvbgqG/1/0813fd'
            +'iYfcxId85IOg/sVc/8G591e5CABiiMCBBIcAKViwiJWFDBs6fMgQS0SIExly'
            +'uYgxo8aNHDtyPHMmDUg0IEGmQZNGZMmVKUOqJFmy5UqYnGravGmzFM5SOnXi'
            +'zMmTE0+fNekYPYo0qdKlTJHOMYqEBw4cUalGRYIVK4+rWrdyjerVa1WtWH34'
            +'CII2bVojZ9UGOWvELVuzP4S8NetDCF4dLQAAcLEksJLAggkPJoz48BLFiQ0T'
            +'pgiZ4ZSFkylLjrwwY5cuFzl35rIZI2fPoDuTBu05NGfErFu7fg2b9aZXtGnP'
            +'nm070yb+Vptu937V+7dt2rw3ZaoNfFOZ5cybO38OPTr0I9SrW7+OPbt27Uq6'
            +'e/8OPrz48eJd+PWwalWr9OrZr2fvHn789LBgyW+/ioqVKfz3V6H8H38CDkhg'
            +'gQRSQYWAVGzGYIMOPghhhBF2YkonFnbCiYUZYqhhhxhW2EkpF3L4YYgjXohF'
            +'iiqqaMWKKbYokRVXxOjiii3C+CIWluzIY48+/ghkkEAGR+RwRN6WXJK3cRIc'
            +'cEoiuclCCCJoRRb6TUmFlVVOaQWCVlJJZZdW8pell074xUEraq7JZputRLEm'
            +'nHGquUoUrripJpwG7slnn31KCGiggnaBXKGGHopoooVewej+jI0yisWjkk5K'
            +'aaWMVoJppppuymmnnnbKSqiijsrKKqSSWp+opsKi6qmh1ldFrLLOSmuttt5q'
            +'axNoviknm73iCaydcvYK551+HovsnoMuyyyhij4LraKWTjtpipJGWu2ln27L'
            +'bbekrvKKq6yweiq5rIQLS7jnnmrqubi+C2+8U+gKAAdRqJenK8Pm++uad+bp'
            +'ppz/tpJswQU3izCg0S7MMG3UXvvwtNhe0W3FFmsaaruurkruK+mFqq64IrMS'
            +'b8kmyzovmgMDi6ecdbIMrMEy+5lwzQ82jPOzEU8MaaU8U4rtxUJ7u+7IIY8s'
            +'Lrinnsx0vPSm+aavc0o9571t9hv+NcEzb12gzV5vlnOhnYT9CtCP/hyx2Y0O'
            +'zbanSJuLdMZxi9p03bc+3crKMFO9HrEBs8l14AJ+7TXZhteWNrVoU9t24xij'
            +'qu4rcM9NOcl2Xy4r3v5eHbWddP6KNcyCC064zYcfLvHDkS5+tqSOv15u5SNr'
            +'nO7SmGOOdxT3+l0nvlMDnHWc+ko9euClQ7hFoKcbnnjzD7/ueKtxKz0q9eKa'
            +'S/3tuKOJtdXABx+8wL+urGfxWx+f8PJkOw8x+xRD3/a3o3pc9NGlnhp50qFq'
            +'f/nT5H//sr5xTm/72pz5zoe+ZqkvbO5r4KPgF7/pyU1Uk5tgqkTGP7tpTm/A'
            +'G97v+Pb+N2MdUGaoSeCgFpiznjmQfRBkG8hoF7cLzq2CGayb5voVus3tDXxr'
            +'GiEJTbgsFOJsZyts1MRaODRXVRB/c9OY7Wp4stxNjYNX810O8eTDZCEIiA5K'
            +'HoSE2LBsFfFnPMMCEoWmRHFJTo1FE1ntYAFFpuGNg/36F7E89z3PCWxNVcji'
            +'sbbIRUGBkWFELKLrzmgxkM3veku8XyPHBclxxTGKuwKe33jlu7/x8Huu8COy'
            +'FhQhLwZykAtzIOsihshE3k92TqTg2+oDx0mWTHNsCiDnvtemOxVQTa7opSeP'
            +'VYVAAsoLXCBltIzYvhWSUVup5NbG1GU9udnvmZHsWCxlCS/+WgLLg6Hb5d6q'
            +'kKBf8kmYymsYbpbnM7UZsplEWyUsIxm72UmPVebCptMqCTA7bnOH4OsVgsQ5'
            +'TnJKyJjQGmPqKMVOZypyXRWsD7oql79R2TOb+Pxgy1iGR1yqKQsADWjNRJk+'
            +'gkrLkOpEaEI/hTQnTu6RcZvou/y3yallNGtXzBsv4cTRjhpIoAMVaaJIysKT'
            +'um2Caaym7DbmUlw97ZIgvGUImapTZfH0iz5FlOKAqkKhDnVdrYTn/FiqqiUm'
            +'9W67+ted9OlUztV0TeGM6oCmSlWCnnNRWEXmtLQKqkW+bVz0ZFUrj1Y7RY41'
            +'VxXVKJ7QOrACFrCtbuUPXG9W1UP+1TVxeOVU5eAmQ1GF7JGmGmytaNnN361V'
            +'dI19qzBB2iAvRFayzjslZSv7uKOKDIYj8yytNshBKrJpZbpdGZgY21FmodZB'
            +'JTxh2ObKwEKqULkzihRsNQVLc2H2naOi56umm1kK2nZW2sxjLu3oQZv6i7ds'
            +'/aeBzJtF9A1XYchBLkHTZq1snbKMzn0upvhKrsxGd1ytkC5+IdnXRm43cyrr'
            +'Zd7MOrBe9lI9Z+Ulgt1k4DtNiUwJ6uOECWThPk4BS2QqkIantN71CldCoIGW'
            +'e93rpCYZamxOghS2Xtzc5roCxi52VHxXNOMZ17dTl0hodCUX3SCnSshC7m90'
            +'V0FkLtjSTcnwYjJhAfABDkiZAx54wpSlXOUrW/nKXM4yB7bMZQ40wQljJrMT'
            +'zHzmNJfZCVJYM5qbMOYmXAHNak4zFO6M5zzrec987jOfOwDoTAQa0IQWNKEL'
            +'fegOGHrQiS60oJ8A6UhLetJPcAKlL01pS086EpzudCQsMAlPc9oCoha1JEqN'
            +'6k4D2gMdYDWrV93qWDeaA4R+daJtXetWw1kKUICzr38NbF+3OdjAHjax/YLs'
            +'ZCt72cxutrOfDe1oS3va1K62ta+NbWYHINvc7ra3vw3uawcEADs=')
     return img

def add_row():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAACFfHSZlIixtJzN1Ljd6MTl9Mzp+NEJ3uzyBNj2C'
            +'N0GHOkKIO0iPQEqSQkuTQ0yVRE2WRVGbSFijT12gVV6rVGOlWmOxWXy+dn7B'
            +'eVKEw1WGxlaHx12KxV+MxlmKyFuKyV6Oy1+Py2OSzmSTzmiW0WqX0W6Z02+b'
            +'1HKe1nSg13Wh13qj2nqk2X2l3H6o3YDBeoTDfoCp3YKq34Ss4Ieu4Yiv4oyx'
            +'44yy5I+05ZC15pO355S355a66Zi66Zq865u9652+656/7InGgorGhI7Jh5PL'
            +'i5fMkpjOkJ3QlKHTmKXVnKTToLDYrLrdtr3fuZ/A7aHB7qLB76PC76bD6anE'
            +'6KrG6azG6azH6K3H6azH6q3H6q7J6a7J6rDI6LDJ6bDJ6rLL6rPM6rXM6LrQ'
            +'67vQ677S67/T69ji8Nvk8dvl8d7n8t7n8+Lq9Obt9urw9+vx9+3y+O7z+e/z'
            +'+fD0+vH2+vL2+vT3+////wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAMAAHkALAAAAAAQABAAAAjPAPMIHEiwYJ4p'
            +'UqAE+dFjhw4cNmjIcMFCYJQ7GDNqxKhCoJA7S5QkQWKkyJAYMDDcQSEQyB08'
            +'MGPKvGNCoI87VHLq3HmHhEAeOPFUiYklJhwRAnPYsXJFSxYuX7B88TJmzQeB'
            +'N+p0wQMmAsyiMNVsEFiDThgxEBqIuVBhggQHDA4QGDBjDp4HFigoMPDESRMm'
            +'R4hkEPBiDpkyCxKUcQtX7gABAVrIMYPnTAGYW2Ki8SBwRZw3btqwSYOmtOkO'
            +'AlOcKDEiBAgOGmLLRmCwdsGAADs=')
     return img

def add_col():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAADdrGT5wIkx7MUR3a09/e1OMKFePLV+JSWCJSWaO'
            +'T3GXX3y+dlKEw1WGxlaHx1mKyFuKyV6Oy1+Py2OSzmSTzmiW0WqX0W6Z02+b'
            +'1HKe1nSg13Wh13qj2nqk2X2l3H6o3YGrYYe5YIe6YIu6Yo26ZIy8ZY+8Z4+7'
            +'aoDBeoTDfpGvnY6uooCp3YKq34Ss4Ieu4Yiv4oyx44yy5I+05ZC15pO355S3'
            +'55a66Zi66Zq865u9652+656/7InGgo7Jh5PLi5jOkJ3QlKHTmKXVnLHTkLLS'
            +'lbHWkrTUlbbUnJ/A7aHB7qLB76PC76bD6anE6KrG6azH6K3H6azH6q7J6a7J'
            +'6rDI6LDJ6bDJ6rLL6rPM6rXM6LfO6rrQ67vQ673R677S67/T69Dmutji8Nvk'
            +'8dvl8d7n8t7n8+Lq9Obt9urw9+vx9+3y+O7z+e/z+fD0+vH2+vL2+vT3+///'
            +'/wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAMAAHQALAAAAAAQABAAAAjTAOkIHEiw4EAm'
            +'SnjowGGjxowYL1p86CBwiZyLGDNe3CCwhxwiQ4QEAfLDh4oUDORkELhDzpyX'
            +'MGPKuSAwhxwnOHPqlFNB4I2bB57AjAJzzQSBNOJAQTFFCpUrUa5Y2WIGgkAZ'
            +'cKocwDIUZhkHAmG8yYJCi1kuUVgsUICggEAXbrgc8AJzRQgkYlAcCEAHhJsu'
            +'KLwI/pKgyJE5Jk7w9dAGzIEwMAckgWmELwc2atKgOUNmjAASI+aIUExHAwYL'
            +'FCREeNCAgIESRkoY4GtwYIDbt+kEBAA7')
     return img

def del_row():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAAEJ3u3y+dlKEw1aHx12KxVmKyFuKyV6Oy1+Py2OS'
            +'zmSTzmiW0WqX0W6Z02+b1HKe1nSg13Wh13qj2nqk2X2l3H6o3eoRHOwaI+4m'
            +'Lu4oMO8sM/AxN/E1OvE2O+RZU/RFSPVJTPZOUPdTVfdUVvhYWedhWPphYPpj'
            +'Yvxvbf54dIDBeoTDfoCp3YKq34Ss4Ieu4Yiv4oyx44yy5I+05ZC15pO355S3'
            +'55a66Zi66Zq865u9652+656/7InGgo7Jh5PLi5jOkJ3QlKHTmKXVnJ/A7aHB'
            +'7qLB76PC76bD6anE6KrG6azG6azH6K3H6azH6q3H6q7I6K7J6a7J6rDI6LDJ'
            +'6bDJ6rXM6LXN6r7S67/T6/mZk/qinPutpvu5sfzDutji8Nvk8dvl8d7n8t7n'
            +'8/zLwf3OxOLq9Obt9urw9+vx9+3y+O7z+fH2+vL2+vT3+////wAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAMAAHEALAAAAAAQABAAAAjMAOMIHEiwYBwk'
            +'R4rw0IHDRo0ZMV60qDBBoJE3GDNqxBhBYI83RIYICQLkhw8WKwS8eSBwxxs4'
            +'MGPKfNNAYI43SXLq3PlmgcAbOOEoidkkppoEAmm4WcLkiRMpVZpUoXJljAGB'
            +'MtpMgWOFaEwxJwTCUKEiBQoSIDpkwEAlCpgRIeK4UGGmzBcvXbhsuQCnhAgT'
            +'HzhYMItWLYYLF7BgAeNhQxwKbLLA0RITSkwwGgRKWJMGzRkyYcCIHl1AIAQH'
            +'DBQgOEBggOvXAQzKLhgQADs=')
     return img

def del_col():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAAHy+dlKEw1WGxlaHx1mKyFuKyV6Oy1+Py2OSzmST'
            +'zmiW0WqX0W6Z02+b1HKe1nSg13Wh13qj2nqk2X2l3H6o3bpDBLhFA7lEA7lF'
            +'A7xCBLxDBbxNBbxWHb1XHrhWIr5bKIRnaYttbsRXHd1kAcdlJ8prL9J2PeFo'
            +'A+52AOp5Be9/GPh2AP93Ef9/GOZ3IYDBeoTDfv+GIeuKQP+STfSdY/WocreT'
            +'ib+Xi4Cp3YKq34Ss4Ieu4Yiv4oyx44yy5I+05ZC15pO355S355a66Zi66Zq8'
            +'65u9652+656/7InGgo7Jh5PLi5jOkJ3QlKHTmKXVnJ/A7aHB7qLB76PC76bD'
            +'6anE6KrG6azH6K3H6azH6q7J6a7J6rDI6LDJ6bDJ6rLL6rPM6rXM6LfO6rrQ'
            +'67vQ673R677S67/T6/a1jfe1jf7Nrv7WuNji8Nvk8dvl8d7n8t7n8+Lq9Obt'
            +'9urw9+vx9+3y+O7z+e/z+fD0+vH2+vL2+vT3+////wAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAMAAH4ALAAAAAAQABAAAAjXAP0IHEiw4MAp'
            +'UZAYISIkyI8eO3JQkCBQCp+LGDNehCAwCR8oT5w0YbJESQwYAfg4EHiET5+X'
            +'MGPyYSCwCJ8qOHPq5KNA4JCbLazAxAKzDgKBQPZc0aAlyxYvWLx0EQOngEAf'
            +'eri0+DIU5psBAnnkAaMhjNkxWG6A2OAhhEAdeMa0KAMTxwk1bGyYsOCnAh4y'
            +'GsoINvMhDY0WMmZg8DPhzpkWaGBuWANzhQY/EezQmSMnjps2HWq4YJECRQY/'
            +'DxosSHDAAAEBIkq8UEGCwwWDBEdk0JDhdkAAOw==')
     return img

def delete():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAPZvALdKK7hKKrpLLrhOLrxLML5PNrxQMr1RNb5TOMFNM9BP'
            +'PsRQNMBTOsxSPMZVQsdXRctZScxbTNtWS9FeU9ddUeZWTOZYTOZZTulZTelb'
            +'T+ZWUOZaUupcUOxfVOddWc9hU9ZgVNdiXNljXdpjX+5mUuBlXOljW+pmXO5q'
            +'XvBkVvNzXdpkYdxkY9tpZN5qZ91qaN9qauNrYeNuY+BpauJwZvJ3Y/N5Y+R4'
            +'ceJ7del7cOh6del/ePaCaPaEbO6KdeqDfe6Efe+GfvCFcPiGcPCMd/iMdvCD'
            +'e/GOevCRf/eRfveTfvmSfvqTf/iUf+6MgfSOge2Tju6Sj/qah/qdi/GclvGd'
            +'lvqjkfSgnvSinvWjn/upnPqrnfOno/WmoferofarovWsofWvpfivpPKtqvS0'
            +'qvi2qPm5r/q6rvzHuvjDvvnLxPnTzPzUzf3b1P3c2P///wAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAHAA'
            +'If8LSW1hZ2VNYWdpY2sKZ2FtbWE9MC40NQAsAAAAABAAEAAAB6GAcIKDhIWG'
            +'cC8sKyKHgzNQaWtqZDQThzNjbmZWU1toORGFM1xtUkhHTExFZTIPhD9sU0o+'
            +'PbU9NmIKgy5hW0QdwME1TzsMgi1mTEJvzM0YKFUFgiNfQzzNzidU0nAhTkoq'
            +'GOLjF0Y4AoMSXykkFeMWG1kLhB8xYMAYFxUVXSABhRBKdDFywgOQLBQAHHLQ'
            +'QEeUKDcSKGwEB8EBAQMoahwUCAA7')
     return img

def new_proj():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAAEJ3u3y+dlKEw1SGxFWGxlaHx12KxVyKxl+MxlmK'
            +'yFuKyV+NyF6Oy1+Py2OSzmSTzmiW0WqX0W6Z02+b1HKe1nSg13Wh13qj2nqk'
            +'2X2l3H6o3YDBeoTDfoCp3YKq34Ss4Ieu4Yiv4oyx44yy5I+05ZC15pO355S3'
            +'55a66Zi66Zq865u9652+656/7InGgo7Jh5PLi5jOkJ3QlKHTmKXVnJ/A7aHB'
            +'7qLB76PC76bD6anE6KrG6azG6azH6K3H6azH6q3H6q7I6K7J6a7J6rDI6LDJ'
            +'6bDJ6rLL6rPM6rXM6LXN6rfO6rrP6rrQ67vQ673R677S67/T69ji8Nvk8dvl'
            +'8d7n8t7n8+Lq9Obt9urw9+vx9+3y+O7z+e/z+fD0+vH2+vL2+vL2+/T3+///'
            +'/wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAAGUALAAAAAAQABAAAAjEAMsIHEiw4EAc'
            +'NlqsSHHCBAkRIDxowCDwxpiLGDNetCDQxZgaNGbIiAHjRQcOAsZQEMhiDJmX'
            +'MGOOkSBQxRgdOHPqHANBIIqbZHbA9AFziwOBJcLw6AHkxxAjPowUUWJFgcAR'
            +'YIiQOTIUZpUCAkN8QZKkbBImPnwUETKFgMAPXpiQeQKziZiXUxgI3ODFyZO/'
            +'T6AsGbxkCgKBGbpEISMFZhCYUxIIvMBFSxYsV6hM2cz5gMAKEyI8aLDAwIDT'
            +'qAMYXE0wIAA7')
     return img

def open_proj():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAABV5ABt5AB57AyF9ACV/ACZ+ECR8FUJ3uy2DAS2D'
            +'CTWHCTCHFzyLEESPFkaQGUqRHFKXIleYKFubKV6fOlygPGKdMGOfMWWfMWih'
            +'NGujN2mjOW6jOG+lPW6kPl+hQ2KjRmalSGilRnSrT3yvVXy+dkmCpVKHpVOG'
            +'vFKEw1WGxlaHx1mKyFuKyV6Oy1+Py2OSzmSTzmiW0WqX0W6Z02+b1HKe1nSg'
            +'13Wh13qj2nqk2X2l3H6o3YGzWoCzYYK1Z4W2ZoW2aom4a466b5C8dIDBeoTD'
            +'foCp3YKq34Ss4Ieu4Yiv4oyx44yy5I+05ZC15pO355S355a66Zi66Zq865u9'
            +'652+656/7InGgo7Jh5bBgJfCgpPLi5jCg57FiJjOkJ3QlKHGiqHHiqXIjajL'
            +'kKnKkKrLka3NlKHTmKXVnLDOlp/A7aHB7qLB76PC76bD6anE6KrG6azG6azH'
            +'6K3H6azH6q7J6a7J6rLK4bDJ6bDJ6rLL6rPM6rfO6rrQ67vQ677S67/T69bi'
            +'6t7n8uLq9Obt9urw9+vx9+3y+O7z+e/z+fD0+vH2+vL2+vT3+////wAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAAJAALAAAAAAQABAAAAjcACEJHEiw4MA2'
            +'a6xQkQLlSZMlSY7syCGQjaOLGDNevCHwiqM0aMB84ZIFi5EiJRzVEFjF0aOX'
            +'MGM6miFwiqM3OHPqdBRDYJSbj+DAnAPz0AuBThrFkVOHjp08czxgwDOIhUAm'
            +'jO480jN0Qw8JglQIVLJoDx8+HThksEDCzIgHKAQiUdTn0R8Nas6YIUNEjIgF'
            +'Anko8vPnz4UzQ4QA8fGjS4UCkHQkAvQo0IQyY8J4CbIlhAGBOBAZKkQoAgQH'
            +'DShoAcHghEAbNGTAcNFiRYoUCj4cMIHAYEECAwgGBAA7')
     return img

def save_proj():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAACBarS5fpjppqj5qqzNoukRtq0RwsFd+u1F/w1N/'
            +'wXy+dl2Ev1SBxFWDxliEw1uGx1uKyV2IyF6Oy1+Py2GKx2CJyWGLyWKLyGWN'
            +'ymWNzGiOzWyLzWiL026K122L2myN3GOSzmSTzmmQzW6TzGiW0WqX0W6X1G6Z'
            +'02+b1HGY0HOZ0XOa1HKe1nWa0Hee2Xmc1Xue1Hie2Hif2Hmf23uc3XCP4XSg'
            +'13Wh13mg2Xqg2Xqj2nuh3Hqk2Xyj232j3n2l3H6l3X6o3YS/UYS/VIDBeoTD'
            +'fpjJb5nJcYKk1oCm3YWi3YCp3YKq34Wo3YGn4YGn4oSs4Ieu4Yiv4oyv5Iyx'
            +'44yy5I+05ZC15pK15pO355S355e26pa66Zq275m46pi66Zq865u9652+656/'
            +'7KG/6qG/74nGgo7Jh5PLi5jOkJ3QlKHTmKXVnJ/A7Z7A76HB7qLB76PC76bD'
            +'6anE6KrG6azG6azH6K3H6azH6q7J6rPH47DJ6rLL6rPM6rfO6rrO77DN87rQ'
            +'67vQ677S67/T68fuh8fujNf0otf2ot7n8///3eLq9Obt9uXx7ebx7ebw7+bx'
            +'7+n05Ojz6urz8+rw9+vx9+318+3y+O7z+e/z+f//4PD0+vH2+vL2+vT3+/H4'
            +'//f7//r7/fr8/fv8/fv8/vz9/v39/v///wAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAAKkALAAAAAAQABAAAAjzAFPFcTMmTBct'
            +'WKxMicIEyI5UqeB8mkix4sQbEMl8asNmjZo0aM4YKbLgUwqIYj6hWsmy5ScT'
            +'EMF8mkOzps1PIiBumYmKDss7LC1RgHjFUx07efCciKEiyYYRLlZgSFWlkx5U'
            +'fFBpCIRqT8syFqRw6uOnLIQ3qEisDAWKSoUmmv6gGoRKgplRpU6ZEkXKiQIh'
            +'mgQNGpzhSxAlPnTkmCGDQY9MhFAVQnUhC5QnP3jQeMECAQ5MlRoxUtSAC6VH'
            +'kSA5ugTjQAsUJUJMiJDAy6QhR5AQkVRjAMTfqRwAWmQIUaJDm5YQAA6xwIMO'
            +'NkB88MDBgICAADs=')
     return img

def prefs():
    img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAAElJSU5OTlFRUVJSUlNTU1hYWFpaWltbW1xcXGFh'
            +'YWJiYmRkZGdnZ2lpaWpqamtra21tbW5ubm9vb3FxcXZ2dnd3d3l5eXp6en5+'
            +'foCAgIGBgYKCgoODg4SEhIWFhYeHh4mJiYuLi4yMjI+Pj5OTk5SUlJWVlZmZ'
            +'mZqampycnJ6enqCgoKGhoaOjo6SkpKWlpaampqenp6ioqKqqqqurq6ysrK2t'
            +'rbCwsLGxsbKysrW1tba2tre3t7m5ubq6ury8vL29vb6+vr+/v8DAwMHBwcLC'
            +'wsPDw8TExMXFxcbGxsfHx8jIyMnJycrKysvLy8zMzM3Nzc7Ozs/Pz9DQ0NHR'
            +'0dLS0tTU1NXV1dbW1tjY2NnZ2dvb29zc3N3d3d7e3uLi4uTk5OXl5efn5+np'
            +'6e3t7QAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAAGYALAAAAAAQABAAAAjUAM0IHGhmCZIh'
            +'BBMOXCImjA2FA6U4MWPkixcdZmzIcEGwSxkuRoRkuYLDxpMxPUQIdIKky5Ut'
            +'XEZusfKEyQWCSa5AafJDRQsjSor0GMgECREtUYBwEEjiiJEoI0B0QEImSxMp'
            +'MAjaQPJDiRcIQ8BYURIlB8EZRnoQsaLABQkWU5RAWcG0CBAfDAwUGJikSJIl'
            +'NGQUEbKDhgOCMbAkeVKlyRIoSYI8kdBA4AsgX2J0+IDESAQJMaxoILhhAgMz'
            +'HZ4sWWDGgACIAjcE0YEANsEIBgZADAgAOw==')
    return img

def plot():
    img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAAC5fpTBiqTBiqjJkrDNmrjRosTVosjZrtTdrtjxy'
            +'vz10wj51wz52xD92xT93xkZwu1prrUJ3xkB4x0F5yUF6ykJ6y0J7zEN8zEN8'
            +'zUR9zkV+0EV/0XCfvY1Sfa5FZe0iK+4mLu4nL+8oMO8rMu8tNPAuNfAxN/Ay'
            +'OPEzOfE2PPE3PPI4PfI5Puc3Qeg4QfI7QPA9Q/I8QfM9QvM/Q8xNYvRCRvRD'
            +'R/RFSPVKTfZNT/dSVPhXWPhYWflcXPldXflhYPpjYvtmZftnZftraY9kk6he'
            +'goyhwJOs0Zyx0P6WlPyZl/61sgAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAAE0ALAAAAAAQABAAAAhzAJsIHEiwoMGD'
            +'AnEgNHhjSYuFBGewgEhwBUQNA1UMJDIkCMEMSTpEeNEkwYECQpj8IEjBQRMX'
            +'HxAYODIAiA8eO3QYkSAwhQmBBAQEIFikRowVKEosrDDwhBIRBjdgoECQRAgQ'
            +'Bi8gaUBR4AQGCrqKHWswIAA7')
    return img

def plotprefs():
    img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAAFU9ETxyvz10wj51wz52xD92xT93xltujUJ3xkB4'
            +'x0F5yUF6ykJ6y0J7zEN8zEN8zUR9zkV+0EV/0XCfvYdfKJxpHYNlK6pkHL56'
            +'GrN3Lbl5LvAyOPEzOfE3PPI4PfI5PvA9Q/I8QfM9QvM/Q8dvIupeM8xNYvRC'
            +'RvRDR/RFSPVKTfZNT/dSVPhXWPhYWflcXPldXflhYPpjYvtmZftnZftraY9k'
            +'k6hegraDGZGKdJaTbaqJQ7yNQr2IScGCNNKIN9mMNtiMONiNONGVK+aBOOS3'
            +'JMGKTMmFQc2NRMWYSdCdRtqUQduVQ9yVQt+ZQNiaVMeXYs+daNilWNejY9W2'
            +'eta4c+e+d+TJVfXfW/XcXvXcX+3KbefLd+3QeO7Tee7Sfe7TfPffY/bdbPDT'
            +'efHUe/LWevfhWvfiW/jiXZOs0Zyx0NuxhdG3kPyZl/61sufAi/nHlPnJke/S'
            +'rPbTrvDStPnjsvzgxP32wv32xP33x//y4P/z5QAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAAH0ALAAAAAAQABAAAAiZAPsIHEiwoMGD'
            +'AlUgNJjCDYiFBEd8gEjQA8QIA6ewWdLHRo0ZBCGsoaDjSh0+c47QeBOD4AID'
            +'fcDYgUPnjhQZMFy0YIEjgcAwecZwoRIFAcEbJ0KY+KJnCxozTwoyGNhFj5Yz'
            +'ZZwMlPBgwUAreMSkIdOEoAM1BQRWaYMlixcmBRUQENCHxx4oGZT8gHghjhwk'
            +'GCgGqOCjB8KAADs=')
    return img

def fit():
    img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAPYAADd1LTh1K/8CBv0NEfwOEvsWGvsXG/kZHPkhJPcrLvkq'
            +'LesqOfYzNvUyOPY2OeExRfU+QfRAQ/FIS+5KUPFNUPJPUu9XWe9YWvBRUzaE'
            +'KziCLD6SL0CKMUGIMkGJMkCPMUSfNUWdNkiaN0abOEiZOUmkOkukPEqiQD1O'
            +'uihjqyhkrChkrShlrillrilmrypmrypmsCposSpositosytptC1qti1rty5t'
            +'uS9uuzBvvTBxvmdgrxFh3hBi3zJywDJzwjNzwzR0xDR1xTR2xiRy3idz3gBX'
            +'4AJX4ANX4ABY4Aph4Bt24SBv4Cx/4DN/4KZbiDeB3zmC3zyG3z+J3j6I3zCB'
            +'4E+S3UuT4AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAFgA'
            +'If8LSW1hZ2VNYWdpY2sKZ2FtbWE9MC40NQAsAAAAABAAEAAAB4aAWIKDhIWC'
            +'Q4aJh1hWgxcXFomIU4IVlhiYhYhNVRARhBITV4M/WEs7DQ6DVVVRUpRYpVgL'
            +'D4NMRERYDE+CpQUHKEpYPDyDCgmCOlgEBElIz4UIgjlYAoQnJiWDBdOFJCLg'
            +'2oQ3gxzmgx8bhDVYAQABhhoZg+yKhjQx+DD7KjAq/ylU2FMUCAA7')
    return img

def start():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhGAAYAKUAAP///+bm/+Xl/uPj/OHh++Df+d7d993d99vb9dvb9NnZ'
            +'8tnZ5tfW8NTU7tLS69DQ6dDP6c3N58vL5cnJ48fH4MTE3sLC3MDAzL/A2b2+'
            +'17u71Lm507e30LW1z7S0zrOzzLCwya6ux6ysxaqqw6iowaenwaWlv6OjvaOj'
            +'vKGguqChup6euJyctZqas5aWr5SUrY+PqI2NpoiIoYaGn4KDm4GBmoCAmTMz'
            +'ZgAAAP///////////////////////////yH+EUNyZWF0ZWQgd2l0aCBHSU1Q'
            +'ACH5BAEAAD8ALAMAAAAVABgAAAanwJ9wSCwaj8ikUogr3p7PJG7RHJpa1xsS'
            +'17lQh7arSWvkzrrfnw3bIhPNoXNVLXYzM+dZaK5m23EVMXgZfHRYbjgRLhUw'
            +'GIV9WUwNLooUj4ZjPzcNJg0sEZeQbQAAm50rEJdhhz+kNwadnY9rka2lBiGc'
            +'DYWrmUKuBSGwDHy0bUSuuAYlBnO9drY3ASEFzFXG0NEBHQHONt/Z2nykpEmu'
            +'S0gA6OvsSUEAOw==')
     return img

def end():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhGAAYAKUAAP///+bm/+Xl/uPj/OHh++Df+d7d993d99vb9dvb9NnZ'
            +'8tnZ5tfW8NTU7tLS69DQ6dDP6c3N58vL5cnJ48fH4MTE3sLC3MDAzL/A2b2+'
            +'17u71Lm507e30LW1z7S0zrOzzLCwya6ux6ysxaqqw6iowaenwaWlv6OjvaOj'
            +'vKGguqChup6euJyctZqas5aWr5SUrY+PqI2NpoiIoYaGn4KDm4GBmoCAmTMz'
            +'ZgAAAP///////////////////////////yH+EUNyZWF0ZWQgd2l0aCBHSU1Q'
            +'ACH5BAEAAD8ALAAAAAAVABgAAAaqwJ9wSCwaj8ikEKdM4hZM5G06HT4vnajx'
            +'1jJ1lwvsLHu8eU02a2cWGmuHXG/a2l5n3j9zd27NzDIxFW9xLXxWGDAVLhFa'
            +'emhHOBSLLg1RhIZEOBEsDSYNN3lnmEsQK52fAACXRjinJgY3qaF7Ra2eIbCy'
            +'eV2FmQyvIQWxAHCiVgYlBrjDRKs/OMgFIQHMzcZLAR3Uus28hjjbxFs25JjV'
            +'R6ncQ+JN7e7vREEAOw==')
     return img

def next():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAACBeHSRjISlpJS9wKjV4LzuANUKIO0WIP0mLREqM'
            +'RUmRQU+ZR1CRSlydVVahTV6hWVypU2KjWmKxWGi4XW2+YXy+dnHDZXTHaIDB'
            +'eoLCfYTDfofFgYnGgovHhY7Jh5DKiZPLi5XMjpjOkJrPk53QlJ/SlqHTmKPU'
            +'mqXVnKfWnqnXoKvYoq7apQAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAAC4ALAAAAAAQABAAAAheAF0IHEiwoMGD'
            +'CBMqXJiQAcOBCw4QxIDhQgUKEyI8YLBAgoMCAzG0YKEChQkSIkB44KChwQCB'
            +'F1akOFFiRIgPHTZksKBAgMCLGTdGNIAAQgKfDAcgZbj0odOnUA8GBAA7')
     return img

def prev():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAACBeHSRjISlpJS9wKjV4LzuANUKIO0mRQU+ZR1ah'
            +'TVypU2SqW2KxWGi4XXi9cnu+cXy+dnHDZXTHaH7AeIDBeoPBeoLCfYTDfobI'
            +'e4fJfIrMf4fFgYnGgovHhYvNgI7Jh5DKiZPLi5XMjpjOkJrPk53QlJ/SlqHT'
            +'mKPUmqXVnKfWnqvYogAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAMAAC0ALAAAAAAQABAAAAhdAFsIHEiwoMGD'
            +'CBMqXChwAsOGEh5O+KDBQYMFChIgOGCgAIGGG1isSHGixIgQHjhcoDBAoIQM'
            +'KlCYICECRAcMFSI8EDDQAQQLDDRy9DhAQACCGB8KTKC0qdOnDwMCADs=')
     return img

def search():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAAHaczXufzXug0H+l05JaEJNbEZVdFJdfGJpiG51l'
            +'H51nIp5mIqNrKKVtK6hwMKpyMq93ObF5PLV9Qbd/RLyES7yNVcWXZMeZZsyi'
            +'dc6kdpKUnYqTooWp1oaq14qu2Yyw24+y3ZGox5O235y6352735a44Zq845u9'
            +'5J/A56LD6KbG66jI7KvL7q7J6K7O8K/P8bXP7LfQ7bTT9LvW87vX87jW9rnX'
            +'973V8L3X873Y877Z87vZ+b3b+r7b+r/c+tWuht21ieTBnejLq8Da9MHa9MLb'
            +'9MPc9MTc9MXd9cbd9cfe9cDe/MHe/Mjd88ne88je9cjf9cnf9crg9cvh9s3h'
            +'9czh9s7i9szi+M3i+dDi9dDj9tHl99Lk99Pl99bn99fn99Pm+Nbn+Nno+Nrp'
            +'+N3q+d7r+d/s+d7s+uHt+eLt+eLu+ePu+gAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAMAAG0ALAAAAAAQABAAAAiTANsIHEiwYEEe'
            +'NmbAaGFwoI8saNaoIYMjRcM2WNh8uUJlS5kYIwzeMPPFyhQoSahoAWFwRhor'
            +'UpYgMUJEjAeDL85EUXKkyI4cYQgYZAHGCk0dNYw8EWBQhYwxUHTQMNKlxIaG'
            +'JlxU8cLFCQkRQCY0/NCBwIAAHDIM0fDgIkEJF4RgUOB2oAMLQRDUHZhgwd6/'
            +'fwMCADs=')
     return img

def transpose():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAPYAACxsJyxtKC1uKC1uKS9xKzFzLDd7MTl9Mzt/NT6EOEGH'
            +'OkKJO0OJPESLPUWMPkaNP0mRQkqSQkqTQ0yVRE6RSU+SSlCZR1GUTFOWTVCa'
            +'SFKcSlOdSlqdVFWgTFahTVijT1mlUFmmUF2qU1+sVV6gWGOlW2WnXWOxWGa1'
            +'W2a2XGm5Xmq6X2mrYWy8YG2/Ym6/YnGyaXK1aXm4cXi6cHu6cnu7dX68dX6+'
            +'dn6/d4HAd4DBeYLCe4XHe4LCfITAfYTDfoXDfoTEfYfEf4fIfInGgo3HhozK'
            +'go/Jh4/KiJLJiZLKi5PLi5TLjJbMjpfMjpjOkJnOkJvPk5vQkp3RlJ7RlqDR'
            +'l6DSlqHTlqHTmKLTmaLUmaTUm6TUnKbVnKfWnqnXoKrYoKvYoQAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAGIA'
            +'If8LSW1hZ2VNYWdpY2sKZ2FtbWE9MC40NQAsAAAAABAAEAAAB4aAYoKDhIWG'
            +'h4iCLisoJ4liLkNXXl5QMx+HLkZhWV1bUVMzFoY8YVxZOjZQUVAshStTV1Mi'
            +'IBsbRUw+DIQppzcggxEPCwmEJ1dXMx2CEYgiSkxKGRNiEAuIMUxMSCYMJBwH'
            +'hxswSD5EQj49GAWHESU1PTo6NxUDiQkJBhf1j4ME9v0EASQUCAA7')
     return img

def melt():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAMZnACxsJy9wKi9xKzJ1LTN2LjV4LzV4MDZ5MDh8Mjp+ND6E'
            +'OEOGPUOKPEeMQUmLQ0iQQEmRQUmRQkuUQ0yRRUyTREyVRE6YRk+YR1OXTFCa'
            +'SFWgTFaiTVejTlikT1unUVuoUlypUl6qVV+sVWCuVmGvV2GjW2KkW2WnXmW0'
            +'WmurY2usZWyvZG+vaGu1YGu8YG66ZHK+Z3GyaHGxa3K0aXOzbXS2bHa2bXa3'
            +'bXi2cHi3cHu5dHq+dXy+d32/d2/BZHDCZXLEZnLFZn/AeYDBdoTFeYLCfITD'
            +'fYXDfofEf4nKforMf4fFgIjFgonGgozGg4vHhIrMgIzIhY/MhZDJiJDKiZLK'
            +'ipTLjJXMjZXMjpfOj5jOkJrPkpvPk57RlqHTmKLUmaTUnKbVnajXn6nXoKrX'
            +'oavYoq3apP//////////////////////////////////////////////////'
            +'/////////////////////////////////////////////////yH5BAEKAH8A'
            +'LAAAAAAQABAAAAeGgH+Cg4SFhoY+QIeDIy0vMFJKQYsaUV5gYmVmUJOFFzhc'
            +'XV9gY2NKioUSU1k3ISNDRC6DBQkKGDRTKxqCKCiEBDxDS0w6FYt/Ajs8RUs4'
            +'D8cAAgQOKksnz38aHosIR9YUGC01H4cGJUtRU1ZcXDUg5TJM6VlZM9vlCw0T'
            +'KykZx4QMsP07FAgAOw==')
     return img

def pivot():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAMZQACFfHiNiICRiICZlIidmIylpJSprJixtKC5vKTByKzJ0'
            +'LTR3LzZ5MDh8Mjp+NDyBNj6EOEGHOkmRQkuUQ06XRlGcSVOeS1mmUGOlXFyp'
            +'U12qU2eoYF+sVWCuVmKxWGW1W2e2XGi4XXO0ane2cHa3bnO5bW2+YnS7b3W7'
            +'cG7AY326dXi9cnDBZHm9c3DCZHDCZXy+cnu+dX2/dn7AeX/BdYDBeoLCfITD'
            +'fofFf4fFgIjFgoXHe4rFg4fIfIvHhI7HhYjKfonKfpHJiZTLjJbNjJbNj5vP'
            +'k57RlaDSl6LUmaXUnKbVnafWnqjXn6rXoavYof//////////////////////'
            +'////////////////////////////////////////////////////////////'
            +'////////////////////////////////////////////////////////////'
            +'/////////////////////////////////////////////////yH+EUNyZWF0'
            +'ZWQgd2l0aCBHSU1QACH5BAEKAH8ALAAAAAAQABAAAAdtgH+Cg4SFhoeIhiYs'
            +'iYQgO0AujX8dNE1OQS+NGTBMTz0pkxpKTSGTfxdJSx+TFSJIRx6NEhRCRD8c'
            +'gwUHCQsNDxEYPEVGJIQDJysxMzY5PjhDKhaEASUoLTI1NzojGxOFAAIEBggK'
            +'DA4Qp+rrgQA7')
     return img

def aggregate():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAMZbACFfHiNiICZlIilpJSxtKC1sKS5vKTBwLDJ0LTN1LzV4'
            +'MDh7Mjl+Mz2CNz6DN0CFOUGHOkOJPEOKPESKPUWMPk6XRk+YR1GXSlSWTlOd'
            +'SlSfS1adTlqeU1qcVFaiTVejTlijT1qiUlmlUF2qU1+sVWGjW2KnWmOmXGWm'
            +'XWWrXGSzWma1W2e3XWi4XWm5XmmrY3OybHO5bXS7b3i5b3i2cHi3cHW7cHi9'
            +'cnm9c32+c3u5dHy6dXu+dX7AdX/AeH7AeYO/eoO/fIHCdoHDd4TDfYXDfofF'
            +'gYjFgonGgovHhY3HhY3Iho/Jh5DKiZHLipLKipLLi5PLi5bNjpbNj5jOkZzQ'
            +'lJ7RlqDSl6LUmaTUm6bVnf//////////////////////////////////////'
            +'////////////////////////////////////////////////////////////'
            +'/////////////////////////////////////////////////yH5BAEKAH8A'
            +'LAAAAAAQABAAAAd+gH+Cg4SFhoeFFBcbIR6Igw9GSU1BII9/DUVHS000loIs'
            +'hQwNEyhKTY6CKi2HEydNOykiIzlDrIYSOlFTVFZYWraGDzRMUVRUV1o5oYQL'
            +'HUcwHRYmQzImgwMGCBhDRg+DGh+EAjI3PDwlDYMWhQExNjwvCpcABQcJBpf6'
            +'+4+BADs=')
     return img

def merge():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAPZlADyANT6DN0CGOUKIO0eGQ0+ZR1CQSlGbSVOeS1ebUFia'
            +'UViZU1WhTV+iWmOnXGesYG2wZ3Gya3a1b3q4dHy+doG9e4C/eoDBeoTDfkJ3'
            +'u1KEw1WGxl2KxV+MxlmKyF6Oy1+Py2OSzmSTzmiW0WqX0W6Z02+b1HKe1nSg'
            +'13Wh13qj2nqk2X2l3H6o3YfCgYnGgp3QlKHTmKXVnICp3YKq34Ss4Ieu4Yiv'
            +'4oyx44yy5Jq865u9652+656/7J/A7abD6aHB7qLB76nE6KrG6azH6KzG6azH'
            +'6q3H6q7I6K7J6rDI6LDJ6bDJ6rLL6rPM6rXM6LXN6rfO6rrP6rrQ67vQ677S'
            +'67/T69ji8Nvl8d7n8uLq9Obt9urw9+vx9+3y+O7z+e/z+fD0+vH2+vL2+/T3'
            +'+////wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAGYA'
            +'If8LSW1hZ2VNYWdpY2sKZ2FtbWE9MC40NQAsAAAAABAAEAAAB6mAZoKDhIVm'
            +'OTc1MywqhkBAPDpkk5MohUCUZC8YFxRkJoU9ZDIxMGWnZWQkhZKoP68/ZCKE'
            +'DAcKsESoXSCDCBUuBj9lQkRLS09ZHoIHEwkBBMREuadYG2YFEgOHY0llS9Lf'
            +'DwgOEQKCNWFLTk5SY6cNFxABgzVgUWVUTlH6CgMAhC3AUBk4rcyVDoVWCMR3'
            +'pWFDDoVQgOmyRYuGixczFDpRgoQIXoZCCgoEADs=')

     return img

def table_multiple():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAPZbAHy+doDBeoTDfkJ3u1KEw1SGxFWGxlaHx12KxVmKyF+P'
            +'y2OSzmSTzmiW0WqX0W6Z02+b1HKe1nSg13Wh13qj2n2l3H+o3InGgpPLi6HT'
            +'mKXVnICp3Yew2ouz3JK434Ss4IWs4Ieu4Yiv4oyx442y4oyy5I+05ZK25ZO2'
            +'5ZO355S355a455u/45i66Zm76Zu965y9652+656/7J+/7KTLxqTLyZ7B5Z/A'
            +'7aLE4aLD5qbD6aHB7qLB76rG6azH6KzG6ajG767I6K7J6rDI6LDJ6bLL6rPM'
            +'6rXM6K7K8Nji8Nvk8dvl8d7n8uXs9+bt9unv+Orw9+vx9+3y+O3z+e7z+vD0'
            +'+vD1+vH2+vL2+vT3+/X4+////wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAFwA'
            +'If8LSW1hZ2VNYWdpY2sKZ2FtbWE9MC40NQAsAAAAABAAEAAAB72AXIKDhIWD'
            +'PDcxKSUiHxsVFIU8WZRZWliVEoUyWTQ4NiweHRwkFpCDL1lIWlqWrFlPWZqC'
            +'LVkyVDU5PIqMjqcqWTFaQJXFlJomWC1UnBoZGBcCAQBZEFwiWCpaqVvd3ltZ'
            +'DlwcVSdUtTrp6jpZDFwUVClYKVk6Wz7fUQpcEQ8fTiWw9PjxwweRIUeYJBg0'
            +'QQoJLELufVtiYFCECB+oEDHio+MQH0kKFJIg5YmTJUlSpkRQqJ8DBgYIyJQ5'
            +'IBAAOw==')
     return img

def filtering():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAPcAAMh/M81/OIF7c9mYP/LSOLmIScWIR9WOSMqTQMmWQ82X'
            +'Q8eaT9eiVcOsa8mvatCpYNK3Ztm0atm2eOe+Y+K7bfbWR/bZRvXZTfbbTurB'
            +'XvXcU/XYVfbaVffdW/LZXvbfX+zJb+zHfvDRfvbgavfic/jmfipgtyxity1k'
            +'uS5kuS5luTBlujBmujFmuzNpvDhxv1dmhlhkh0J5vzt2xDx4wUV+wkB8xGyD'
            +'l3aYqUKAxUWCxUaCxEaDxkeExkmFxEuIxUuJxUmIxkqIxkuJxkyJxk+Lx02L'
            +'yE+MyE+NyE+MyWSS22WU226sz1S191a091O0+FW0+H2w4X2y4ma38GW++2e9'
            +'/Gi//W7C/c23jM69ntS8k869rLLAtPDUgPTdifbigPnphvbimfjomtTFqefQ'
            +'qvjmofnuqfvwo4S24p7X/6DY/7PS8bXU87jW9LrW9bvW9bTY9rzZ9vvzycLb'
            +'9sHb+MLc+MTd+cXf+cff+sfg+sjg+cjg+sjg+8nh+8rh+sni+8vi+8zh+83j'
            +'+87j+8nl+s3j/M/j/M/k/M3m/Nfm8t/p9N/r9d7q9t7r9t/s99Dk+9Hk/NPl'
            +'/NPl/dLm/NPm/NPn/dTm/NTm/dXm/dXn/dbn/dXl/tbn/tfn/tbo/tfo/tjo'
            +'/uPt9+nv9ebw9+zy9+jx+Orx+Ovy+Ozy+O3z+Ozz+e30+O30+e70+O/0+fXz'
            +'8vD0+PD0+fH1+fL2+vP3+/P3/PT4/Pj7/fj7//3+/gAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAALoAIf8LSW1hZ2VNYWdpY2sKZ2FtbWE9'
            +'MC40NQAsAAAAABAAEAAACPMAdekycqSgwSJEZghc6INUq1anVEkklUjKkoW6'
            +'fszK4weQnzt03NiCE+WiQI2FBhUChKeOm1uICKGRcXJWykeFPsZRpIqWqBo1'
            +'K0WqhLOlGzZrZu0QGKTVp0hPKw26MwdLBDJLMzoFBeqpJDxZQMiZcENgD1Wf'
            +'uEZaOybDmS4hGAjcoQpqJFBCJZj5IkZEiQO6cpwSOvTRIy1eRojooGGALhuj'
            +'oDiB8oRJAwgeMGjYAEAgjVBW0qTh8iCMBgsIDByAIXAGaCpXHJQhUCEBjimv'
            +'WAh0IUpRI0UUwFxQsIWWrVwnFrJowYKFgAUFYqhQwSK5roAAOw==')
     return img

def importcsv():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAOe1ACpgtyxity5kth57AyxltC5luS9lujBluiJ7DjBmuiN6'
            +'HTFmuyV/ADNpvDhxvzWHCjt2xDx4wTuLETqMFUJ5vz98xEB8xEOPF0V+wkKA'
            +'xUKAxkiRG0mRHUWCxUWCxkaCxEaDxkeExkaULkmFxEqUMkmIxkqIxkuIxVGX'
            +'I0uJxUuJxkyJxleYKE2LyE+Lx0+MyE+MyU+NyFubKWOeMl6fOmOfMVygPGWf'
            +'MV+hQ2SS22miNmKjRmWU22ujN2ukQWalSG+kOmilRm+lPXKoRnSrT3yvVYGz'
            +'WoCzYYK1Z1W0+Fa091S194W2ZoW2aom4a32w4X2y4o66b5C8dIS24me9/GW+'
            +'+2i//ZbBgJfCgm7C/ZjCg57FiKHGiqHHiqXIjanKkKjLkKrLka3NlLDOlrPS'
            +'8Z7X/6DY/7XU87jW9LrW9bvW9bTY9rvY9rzZ9r3a9sHb+MLc+MTd+cXf+cff'
            +'+sfg+sjg+cjg+sjg+8nh+8rh+szh+8ni+8vi+83j+83j/M7j+8/j/Mnl+s/k'
            +'/NDk+9Hk/M3m/NPl/dLm/NXl/tPm/Nfm8tTm/NTm/dPn/dXn/dbn/dbn/tfn'
            +'/tbo/tfo/tjo/t/p9Nzq9t7q9t7r9t/r9d/s9+Pt9+nv9ebw9+jx+Orx+Ory'
            +'+uvy+Ozy9+zy+Ovz+uzz+e3z+O30+O30+e30+u70+O/0+e/0+vD0+PD0+fH1'
            +'+fL2+vP3+/j7+Pj7/fj7////////////////////////////////////////'
            +'////////////////////////////////////////////////////////////'
            +'////////////////////////////////////////////////////////////'
            +'////////////////////////////////////////////////////////////'
            +'////////////////////////////////////////////////////////////'
            +'/////////////////////yH+EUNyZWF0ZWQgd2l0aCBHSU1QACH5BAEKAP8A'
            +'LAAAAAAQABAAAAj+AP/9a/Gi4IsYMFykgCCw4QhRqk6ZmjhKlCIoPBr+OwGL'
            +'Dp49d+S8QUNrzZMcDVe88vOnD586cNLMKhRoCgWBKl4BGiTIT544bSqJisUJ'
            +'A05XiRY1ItTHDhw1Z8i0+iDQxKpIjxwxOqRnDhw3bFiBEFgCFSVKkyAZIqRn'
            +'yA04qTwIDFFK0qRHWQ0N8mGEBSgNAjuEgoRXCBAdM4qEIbKhgsAMnhAZMtRj'
            +'jJgwYKR0CfJAoIVOSZQsqSEmihMmR5BoscHgX4RNWcyUkfHFC5ctTbD8UCDQ'
            +'QSYrVKqg4HBBAo0rO0QQENjgkyZMlyxZIkVqAg4SsgA0PLAggfcDBgoHIBgg'
            +'IIDAgAA7')
     return img

def excel():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAOenACpgtyxity1kuS5kuS5luTN0GS9lujBlujN1GTN1GjN1'
            +'GzBmujFmuzFnuzNpvDd4HzZvvzhxv0F/LkJ/Ljt2wTt2xEWCNjx4wT9+f0iE'
            +'OkJ5vz98xUB8xEV+wkKAxlKKREWCxkaCxEaDxliNQ1iNRFaMVUmFxFOLb1mO'
            +'REmIwkuIxVuQR0uJxUyJxl2RSE2LyE+Lx1+TSk+MyE+MyWCTVU+NyFyWSWCW'
            +'S2OVVGSWV2aWU2SXUGWWV2SXUWKXYmaXWWiaZ2ubYWSS22WU23GeYXCeaG6g'
            +'W26hWXOgbHSkXWqrYXWuZ3G2XYOujYK2cX2w4ZC0kH2y4oS7eIe8c4TAaoS2'
            +'4orBbZW5oZXIdJfJdqHBsaPTgr7TtbTR6bPS8bXanLXU88PWu7jW9LrW9bTY'
            +'9sjZwLvY9sLZ5b3a9szcxcHb+M3dx8Pc9MLc+MPd+cXf+cbf+sff+sfg+sjg'
            +'+cjg+8ng+8zg9cjh+8nh+8vh+8zh+8ni+8vi+8zi/M3i/Mzj+83j+83j/M7j'
            +'+8nl+tDk+9Hk/M3m/Nfm8tzq9t7q9t7r9t/r9d/s9+Pt9+nv9ebw9+rx+Ory'
            +'+uzy9+zy+Ovz+u3z+O30+O30+u70+O/0+vD0+PH1+fL2+vL3+/P3+/P3/PT3'
            +'+/T4/PX5/Pf6/fj7/fj7//3+/v//////////////////////////////////'
            +'////////////////////////////////////////////////////////////'
            +'////////////////////////////////////////////////////////////'
            +'////////////////////////////////////////////////////////////'
            +'////////////////////////////////////////////////////////////'
            +'////////////////////////////////////////////////////////////'
            +'/////////////////////yH+EUNyZWF0ZWQgd2l0aCBHSU1QACH5BAEKAP8A'
            +'LAAAAAAQABAAAAj4AP/9eyGjoIwaM2CwqCCwoQlJmCxVmjhJ0qEoQxr+U8FJ'
            +'Dp49dN6oEVOKzBMhDVtsCiQIEJ85bcaQMjSoioZ/I0rowHGlyQQJGSxAkeTJ'
            +'UQecXL5gwREjyZEdPrqA8aIphMATZbZYwXGjBxA2bdCYySRCYAoiabJMGUHD'
            +'jh45btpcAiEQwwMXa6g4QaGF0J84cCJ5EKjAiI0Va5gsIaHATx48nTb8S5AA'
            +'QYEPQcJIUZKjT507oygI5PCoUKEzRXj8QGK6kCgIAi80ak27NagGAiMsql2b'
            +'lACBDiAxUpQIESJKlCJ9CmUKQMMDDBZIP2CAAIEBAwIIDAgAOw==')
     return img

def add():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAPZ2ADSBLDSCLDeELzmFMDyHMj2INECJNkKNNkKLOEOPOESM'
            +'OkeOPFOWRVCZQVeeRVaYSF2cTV+eUGajVmWrVWirU2mlWGuqWGyqWmqsW261'
            +'WG+1WG+1WXS3W3S3XHC4WXK5W3O6XHG+X3WsYXeuY3qvZXyxZ3i0ZHe8YHy6'
            +'ZH28Zn2+Z36yaX25an25a3+5bXm9bnDBY3nBZH7BaXzDa3rGa37Hb4CzaoO1'
            +'bYS2boe4cIe4cYm+eI2+e4HMdYrCeY/CfYbJeoXNeYbJfInIf4rPfYzLgY7M'
            +'hJLFgJfHhZfMhZjLhpjMh5PNiJjMio7Sg5bTiZTTipXUipbUi5fVi5nRi53Y'
            +'kqTOlKbPlqbQlqDZlaDZlqvUnKrUnaXbm6/fpa/fprPZpbTZpbTaprLbqLXb'
            +'qLfaqrPdqbTdqrbdrLXfrLjdr7vcr7fgr77itr3ktsvmw8XowM7pydTrz9fu'
            +'0tzx2ODy3P///wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAHcA'
            +'If8LSW1hZ2VNYWdpY2sKZ2FtbWE9MC40NQAsAAAAABAAEAAAB6SAd4KDhIWG'
            +'dzg2KyOHgzlWb3JxaC4VhzlrdW5dVWZwPhGFOWV0VUxGUVNObC4PhEhzWVBD'
            +'dnZBMjVsDoM3aF9FQi+1GCcgVEcLgittU0C1z3YeMlwIgiRnRD3QtR4qXAWC'
            +'Ik1QNDAT3B4eSTwDgxRnMSEn3BkdYgmEEixjxR4Z9WAuBCgEwUSZJSlQKBEj'
            +'8BCDBj+wWNlxYGCjOwkMEBBwseOgQAA7')
     return img

def cross():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAPYAAOQiJOYqLOktL+ovMekyNes0Nuw8Pu49P+0+QO0/QfE/'
            +'Qe5AQu5BQ+9DRu9ER+9FSPJFR/BGSPBGSfRISvZKTPJMT/RNUPVOUPNRVPdV'
            +'V/9UV/ZVWPVWWPZWWf9WWfZYWvZYW/ZZW/ZaXPZaXfdbXfdcXv9YW/9bXvdd'
            +'YPdfYfheYfhfYvphY/9iY/hhZPhiZPpiZfljZvpjZvpkZ/9naPloavtpbPpq'
            +'bfxrbvpsbvttb/9sbvttcP9ucP9wcf9wcv9wc/1xdP5xdP9xdP9ydPxzdv10'
            +'d/90dv52ef92ef93ef93ev95e/15fP95fP95ff56ff96ff97fv98fv9+gP5+'
            +'gf9+gf+Chv+HigAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAFkA'
            +'If8LSW1hZ2VNYWdpY2sKZ2FtbWE9MC40NQAsAAAAABAAEAAAB32AWYKDhIWG'
            +'h4dLS4YvNRiES1ZWQoQrPFMrhEJQWFA3gis3UCkShThCV0IvKTdMKQ+HMTxW'
            +'U0xLJQ6IWSNQJyZCDbpZJUseGj+liCMxQj89OxkGhyMvQh8MBhY0FgWF1D8Z'
            +'DIIEEC0UAoQbLBsIhAEKFAOFFe2FAPLC+fpZgQA7')
     return img

def accept():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAPeGAB1sGh5uGh5wGh5xGh9xGx5zGh94Gx56Gx96Gx5/Gx+D'
            +'GyCKGyCIHC2WHC+WHDKdHUKpH0KrH0KtH0yXPUu0JlK5K1K7LVS7LVS9MVW+'
            +'NFXANFnCNlvCOU6bQVKgQl6pSGSwTGy2Vm23V2q5UG61WG+1WG+1WXC/V3S3'
            +'W3S3XHC4WXG5W3K5W3O6XHG+X323Zne8YHy6ZH28Zn2+Z3+4aXTCWW/CYW/D'
            +'YW7EYW7EYm7FY2/GZHDBY3HEY3TDZHDHZXPHZnnBZH7BaX7Hb3LIaHTIaHXI'
            +'aHbJaXbKannJa3rMbX/KcIO+bYfCcoXFdYnEdoDKc4DMcoPOd4fJeYvIeJDO'
            +'f5bHg5rHh5bLhpfMhZjLhprKh5jMh5bNiJnNip3Oi5nRi5nQjJrUjZ/SkZvX'
            +'kZ3YkqHWlaHXlaPXlqvSm6vTm6/XoK7Xoa7cpa/cprPZpbTZpbTaprHdp7Lb'
            +'qLXbqLTdqrTfrLXfrLXhrrfhr7fhsL7jtr/juMDkudbu0tns1Ob04+336/H5'
            +'8PT68vz9+/3+/f///wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAAIcAIf8LSW1hZ2VNYWdpY2sKZ2FtbWE9'
            +'MC40NQAsAAAAABAAEAAACMEADwkcSLCgwUMcMFiocHDghhpo2rQ5M0LCQQ1V'
            +'8pSRIqVMnicPCmbIqMQIESNGkth50oDgiTxKiOyY2WPPkDwfBl44Q8bITBs2'
            +'+BgCBOYLA4EU5EQhksePjT2GCIURwiaBwAhtokARZChQ1C4sZqxBIBCCmTA+'
            +'pgwyZAhLCBZYrpAVCKJOEBdO/ngJQSJFnA4EHTSZA6MFCxIkULyhMaDgAiZx'
            +'uMSIsSVODAAHGXjgkiaNlQmYGx5CUAAAAdGoBwYEADs=')
     return img

def calculate():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAPZaAHJycnp6en5+fttYUuh0c01yp1Z7sGSLwWaNw2eNw2eP'
            +'xWiPxWmQxmuSyGyUym6VyoKDhIODhIaGhoaGh4aHh4eHh4eIiIiIiIiIiYiJ'
            +'iYqKiouMjI2NjYyNjo6Ojo+Pj5GRkZGRkpGSkpOTk5SUlJWVlZeXl5mZmZmZ'
            +'mpmampubm5ydnp2dnp6enp+goaCgoKKioqOjo6SkpKWlpaioqKmpqaurq6ys'
            +'rK2trbCwsLGxsbKysrS0tLu8vLy8vL+/v8HCwsLCwsXFxcnJyc7OztHR0dLS'
            +'0tPT09fX19jY2Nra2tvb29zc3N/f3+Dg4OHh4eLi4uPj4+Xl5ebm5ufn5+jo'
            +'6Onp6evr6/v7+/z8/P///wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAFsA'
            +'If8LSW1hZ2VNYWdpY2sKZ2FtbWE9MC40NQAsAAAAABAAEAAAB6mAW4KDhIWD'
            +'AC0zNjg4izMzLQKEJlqVlpcnhDBaBZ2enVothDNaBgcJCgsNDQZaMJqlqKoP'
            +'D60umlhKSEZEQ0JAP66wOB5KMxpEBANYooMrWlBQTEtIR0ZFWiuEJ1o7IVA4'
            +'H0w2HliZg5RUU1PRTk1MWiaEId0mVDsjUTkhWCGEG1quXLFShYq6KVo2EJIA'
            +'xIePHhAjApFAKEAEChg1aKBggQKEAIZCFgoEADs=')
     return img

def table_delete():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAPZ5ALlEA7lFA7xCBLxDBbxNBbxWHb1XHrhWIr5bKN1kAeFo'
            +'A+52AOp5Bfh2AO9/GP93Ef9/GMdlJ8prL9J2PeZ3IYRnaYttbny+dv+GIeuK'
            +'QP+STfSdY/WocoDBeoTDflKEw1WGxlaHx1mKyFuKyV6Oy1+Py2OSzmSTzmiW'
            +'0WqX0W6Z02+b1HKe1nSg13Wh13qj2nqk2X2l3H6o3beTib+Xi/a1jfe1jYnG'
            +'go7Jh5PLi5jOkJ3QlKHTmKXVnP7Nrv7WuICp3YKq34Ss4Ieu4Yiv4oyx44yy'
            +'5I+05ZC15pO355S355a66Zi66Zq865u9652+656/7J/A7abD6aHB7qLB76nE'
            +'6KrG6azH6KzG6a3H6azH6q7J6a7J6rDI6LDJ6bDJ6rLL6rPM6rXM6LfO6rrQ'
            +'67vQ673R677S67/T69ji8Nvk8dvl8d7n8t7n8+Lq9Obt9urw9+vx9+3y+O7z'
            +'+e/z+fD0+vH2+vL2+vT3+////wAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAHoA'
            +'If8LSW1hZ2VNYWdpY2sKZ2FtbWE9MC40NQAsAAAAABAAEAAAB8SAeoKDhIWD'
            +'VFFPTktJSUZEQkAxL4JUeJeYd3eYeC2CUHg9PDs6OTg3Hh0XdyyCTnh5sbKz'
            +'eCmCTHhSuru8eCeCSrl5VrJYsnElgkd3VljOW11XXV1ibCKCRnhdeduxW7Jr'
            +'IIJEdF1h52FiVzMIAwYVgkJzY3llsjQTNT8cEoIyc2UCBjRzoIaGBxgyANAD'
            +'Y86ZPGZkCfAhy8EAPS3mwHnjhs2aNAU2YGiwQMFCFipSnCgxAsQHCxEoMEhA'
            +'wJAhAAMW6gkEADs=')
     return img

def function():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAPUAACYmJikpKSoqKi0tLS4uLi8vLzExMTIyMjQ0NDU1NTc3'
            +'Nzo6OkBAQEVFRUdHR0hISElJSUxMTE5OTk9PT1FRUVJSUlVVVVZWVlhYWF1d'
            +'XWNjY2RkZGZmZmhoaGpqam1tbW9vb3JycnNzc3Z2dnd3d3t7e35+foGBgYuL'
            +'i5CQkJubm5+fn76+vgAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAC0AIf8LSW1hZ2VNYWdp'
            +'Y2sOZ2FtbWE9MC40NTQ1NDUALAAAAAAQABAAAAZEwJZwSCwaj8iTqVQSfTob'
            +'pIklckIzyBYqRcRkW6vod7hRjbuVc8uSPlsmkCEiCycSkJOGcGEgCJANDAsI'
            +'fQIAaoiJX0EAOw==')
     return img

def copy():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAPZtAEJzxUR0xUV1xkV1x0d5x0h9w0l5x0p5x0V1yEZ1yEt5'
            +'yE58yFN/ylCDylODylSAylKEylOFy1SFylWFy1SGy1WGy1aGy1eHy1KDzFOC'
            +'z1WDzFaBzlWGzFaGzFeHzFWFz1iHzFaIy1aIzFeIzF+WzGWVzW2e0Gyg0Yi7'
            +'6pG65JG75JK75JO75Ja+5Za/5pPB7J3D6q/R87TT9bvX9rzZ98Lc+cLc+sTd'
            +'+cTe+cXe/Mjf+sfg+8Ti+srg+svj+8zi+8vi/83i/M3j/N3p9dDk/NHk/NHl'
            +'/dLl/NLl/9Tm/dbn/dXn/tXn/9fn/9np/9vq/+fx7+jy7+Pv+uTv+ufw+ufy'
            +'+ufy/ejx+unx++vz+ury++vy++71++/2++jy/Onz/erz/ejz/uzz/O70/e31'
            +'/vD2/vH3/vD3//H3//L3//P4+/P5/v7//////wAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAG4A'
            +'If8LSW1hZ2VNYWdpY2sKZ2FtbWE9MC40NQAsAAAAABAAEAAAB7+ABBwjISES'
            +'EG6JiooSbWCPUlUoH4uKHGM5OzUyazwvBZVul0JCOzRDWWsloRJrRkY/NzAt'
            +'KionJiSKEWtKSkY9LY5gVVSSHG4RaExKTEUsmJqcO58QaE7XTM9CPqZDW2oY'
            +'GFxOT05KKmdGRbEzMlISG1Hk5iprTExGOjc0YCALw1O2bHl2T0kRHzasSDig'
            +'AMEAhxDOXDNnxMeaY5UwjJmHT8iYDaHicTQiJArISgcEBhQIZsyDUAAGyHT4'
            +'MACDQAA7')
     return img

def paste():
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAPYAAEZGRkhISElJSUpKSkxMTE9PT1JSUlNTU1VVVVZWVlhY'
            +'WFpaWl5eXmVlZWhoaGpqapVjJJhjIKFuLqR1N4FoSohzWJ+HaaCGY6GHZKGI'
            +'ZKmLYaGFaKOIbKWLb6eOcKSOdaqRc6yUdcaERM2HQ8eIR86LRsmMSs+OSNCP'
            +'SMuRTM2VT9uVQdyVQtyWQtyWQ9yXRNGTStKTS9GUS9OXTdOYTtSYTtqbSt6b'
            +'S9+dTs+ZUtWcUNWdUNacUNaeUdWeU9efUtegU9ejV9ikWNmlWtmnXNqoXtGf'
            +'YtelYtijYtikYtmmZNuqYdyrYtqoZd2uZdyraNyuad6yad6xa96ybN+zbduz'
            +'ceC0buC1cOG3c+K5duO7euS9fOS/fuS/f/DUdbOzs7S0tLW1tba2tre3t/Pb'
            +'gP3utf7vtubm5ufn5+jo6Onp6ezs7O3t7e7u7u/v7/Dw8PHx8fLy8vPz8/T0'
            +'9Pf39/j4+AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAHYA'
            +'If8LSW1hZ2VNYWdpY2sKZ2FtbWE9MC40NQAsAAAAABAAEAAAB82AdoIRhIWC'
            +'h4eEE2VkZGUShIh2EVVcOGVeXmU4VFQRiBFcUTYvLyynP1GfiVxOS0SwsEA4'
            +'q4Narz+5P7NLtZNZREJAPxoYGRgcDQ4ODZNYQbk5IXRxcXBycnBzDBFYPzw1'
            +'KiBwY2Lm5m0LEVY8MzEpHnBqamlo9m0JEVAzMDAmHHLOgRm45oC+fiVEcHCT'
            +'Js0Ze2faFIjwBEWJESI2wBnIEcwaAhGSKFGSxMgHN/YgnlkjYFIhCBXovHnj'
            +'xs1MOQAkCVKA4EABAgQC5AwEADs=')
     return img
